@@ -25,8 +25,8 @@
 
 
 //==============================================================================
-CoordinateConverterAudioProcessorEditor::CoordinateConverterAudioProcessorEditor (CoordinateConverterAudioProcessor& p, AudioProcessorValueTreeState& vts)
-    : AudioProcessorEditor (&p), processor (p), valueTreeState (vts), footer (p.getOSCParameterInterface()),
+CoordinateConverterAudioProcessorEditor::CoordinateConverterAudioProcessorEditor (CoordinateConverterAudioProcessor& p, juce::AudioProcessorValueTreeState& vts)
+    : juce::AudioProcessorEditor (&p), processor (p), valueTreeState (vts), footer (p.getOSCParameterInterface()),
       panner (*valueTreeState.getParameter("azimuth"), valueTreeState.getParameterRange("azimuth"), *valueTreeState.getParameter("elevation"), valueTreeState.getParameterRange("elevation")),
       xyzPanner (*valueTreeState.getParameter("xPos"), valueTreeState.getParameterRange("xPos"),
               *valueTreeState.getParameter("yPos"), valueTreeState.getParameterRange("yPos"),
@@ -40,7 +40,7 @@ CoordinateConverterAudioProcessorEditor::CoordinateConverterAudioProcessorEditor
 
     // make title and footer visible, and set the PluginName
     addAndMakeVisible (&title);
-    title.setTitle (String ("Coordinate"), String ("Converter"));
+    title.setTitle (juce::String ("Coordinate"), juce::String ("Converter"));
     title.setFont (globalLaF.robotoBold, globalLaF.robotoLight);
     addAndMakeVisible (&footer);
     // ============= END: essentials ========================
@@ -53,39 +53,39 @@ CoordinateConverterAudioProcessorEditor::CoordinateConverterAudioProcessorEditor
     gcCartesian.setText ("Cartesian Coordinates");
 
     addAndMakeVisible (gcRange);
-    gcRange.setText ("Normalization / Range Settings");
+    gcRange.setText ("Normalization / juce::Range Settings");
 
     addAndMakeVisible (gcReference);
     gcReference.setText ("Reference Position");
 
     addAndMakeVisible (sphere);
-    panner.setColour (Colours::white);
+    panner.setColour (juce::Colours::white);
     sphere.addElement (&panner);
 
     // ============== BEGIN: SPHERICAL COORDINATES ============
 
     addAndMakeVisible (slAzimuth);
     slAzimuthAttachment.reset (new SliderAttachment (valueTreeState, "azimuth", slAzimuth));
-    slAzimuth.setSliderStyle (Slider::RotaryHorizontalVerticalDrag);
-    slAzimuth.setTextBoxStyle (Slider::TextBoxBelow, false, 50, 15);
+    slAzimuth.setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
+    slAzimuth.setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 15);
     slAzimuth.setReverse (true);
-    slAzimuth.setColour (Slider::rotarySliderOutlineColourId, globalLaF.ClWidgetColours[0]);
-    slAzimuth.setRotaryParameters (MathConstants<float>::pi, 3*MathConstants<float>::pi, false);
+    slAzimuth.setColour (juce::Slider::rotarySliderOutlineColourId, globalLaF.ClWidgetColours[0]);
+    slAzimuth.setRotaryParameters (juce::MathConstants<float>::pi, 3 * juce::MathConstants<float>::pi, false);
     slAzimuth.setTooltip ("Azimuth angle");
 
     addAndMakeVisible (slElevation);
     slElevationAttachment.reset (new SliderAttachment(valueTreeState, "elevation", slElevation));
-    slElevation.setSliderStyle (Slider::RotaryHorizontalVerticalDrag);
-    slElevation.setTextBoxStyle (Slider::TextBoxBelow, false, 50, 15);
-    slElevation.setColour (Slider::rotarySliderOutlineColourId, globalLaF.ClWidgetColours[1]);
-    slElevation.setRotaryParameters (0.5 * MathConstants<float>::pi, 2.5 * MathConstants<float>::pi, false);
+    slElevation.setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
+    slElevation.setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 15);
+    slElevation.setColour (juce::Slider::rotarySliderOutlineColourId, globalLaF.ClWidgetColours[1]);
+    slElevation.setRotaryParameters (0.5 * juce::MathConstants<float>::pi, 2.5 * juce::MathConstants<float>::pi, false);
     slElevation.setTooltip( "Elevation angle");
 
     addAndMakeVisible (slRadius);
     slRadiusAttachment.reset (new SliderAttachment (valueTreeState, "radius", slRadius));
-    slRadius.setSliderStyle (Slider::RotaryHorizontalVerticalDrag);
-    slRadius.setTextBoxStyle (Slider::TextBoxBelow, false, 50, 15);
-    slRadius.setColour (Slider::rotarySliderOutlineColourId, globalLaF.ClWidgetColours[2]);
+    slRadius.setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
+    slRadius.setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 15);
+    slRadius.setColour (juce::Slider::rotarySliderOutlineColourId, globalLaF.ClWidgetColours[2]);
     slRadius.setReverse(false);
     slRadius.setTooltip("Radius (normalized)");
 
@@ -100,17 +100,17 @@ CoordinateConverterAudioProcessorEditor::CoordinateConverterAudioProcessorEditor
 
     addAndMakeVisible (tbAzimuthFlip);
     tbAzimuthFlipAttachment.reset (new ButtonAttachment (valueTreeState, "azimuthFlip", tbAzimuthFlip));
-    tbAzimuthFlip.setColour (ToggleButton::ColourIds::tickColourId, globalLaF.ClWidgetColours[0]);
+    tbAzimuthFlip.setColour (juce::ToggleButton::ColourIds::tickColourId, globalLaF.ClWidgetColours[0]);
     tbAzimuthFlip.setButtonText ("Flip");
 
     addAndMakeVisible (tbElevationFlip);
     tbElevationFlipAttachment.reset (new ButtonAttachment (valueTreeState, "elevationFlip", tbElevationFlip));
-    tbElevationFlip.setColour (ToggleButton::ColourIds::tickColourId, globalLaF.ClWidgetColours[1]);
+    tbElevationFlip.setColour (juce::ToggleButton::ColourIds::tickColourId, globalLaF.ClWidgetColours[1]);
     tbElevationFlip.setButtonText ("Flip");
 
     addAndMakeVisible (tbRadiusFlip);
     tbRadiusFlipAttachment.reset (new ButtonAttachment (valueTreeState, "radiusFlip", tbRadiusFlip));
-    tbRadiusFlip.setColour (ToggleButton::ColourIds::tickColourId, globalLaF.ClWidgetColours[2]);
+    tbRadiusFlip.setColour (juce::ToggleButton::ColourIds::tickColourId, globalLaF.ClWidgetColours[2]);
     tbRadiusFlip.setButtonText ("Flip");
 
     // ============== END: SPHERICAL COORDINATES ============
@@ -131,23 +131,23 @@ CoordinateConverterAudioProcessorEditor::CoordinateConverterAudioProcessorEditor
 
     addAndMakeVisible (slXPos);
     slXPosAttachment.reset (new SliderAttachment(valueTreeState, "xPos", slXPos));
-    slXPos.setSliderStyle (Slider::RotaryHorizontalVerticalDrag);
-    slXPos.setTextBoxStyle (Slider::TextBoxBelow, false, 50, 15);
-    slXPos.setColour (Slider::rotarySliderOutlineColourId, globalLaF.ClWidgetColours[0]);
+    slXPos.setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
+    slXPos.setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 15);
+    slXPos.setColour (juce::Slider::rotarySliderOutlineColourId, globalLaF.ClWidgetColours[0]);
     slXPos.setTooltip ("x coordinate (normalized)");
 
     addAndMakeVisible (slYPos);
     slYPosAttachment.reset (new SliderAttachment(valueTreeState, "yPos", slYPos));
-    slYPos.setSliderStyle (Slider::RotaryHorizontalVerticalDrag);
-    slYPos.setTextBoxStyle (Slider::TextBoxBelow, false, 50, 15);
-    slYPos.setColour (Slider::rotarySliderOutlineColourId, globalLaF.ClWidgetColours[1]);
+    slYPos.setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
+    slYPos.setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 15);
+    slYPos.setColour (juce::Slider::rotarySliderOutlineColourId, globalLaF.ClWidgetColours[1]);
     slYPos.setTooltip ("y coordinate (normalized)");
 
     addAndMakeVisible (slZPos);
     slZPosAttachment.reset (new SliderAttachment(valueTreeState, "zPos", slZPos));
-    slZPos.setSliderStyle (Slider::RotaryHorizontalVerticalDrag);
-    slZPos.setTextBoxStyle (Slider::TextBoxBelow, false, 50, 15);
-    slZPos.setColour (Slider::rotarySliderOutlineColourId, globalLaF.ClWidgetColours[2]);
+    slZPos.setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
+    slZPos.setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 15);
+    slZPos.setColour (juce::Slider::rotarySliderOutlineColourId, globalLaF.ClWidgetColours[2]);
     slZPos.setTooltip ("z coordinate (normalized)");
 
 
@@ -162,19 +162,19 @@ CoordinateConverterAudioProcessorEditor::CoordinateConverterAudioProcessorEditor
 
     addAndMakeVisible (tbXFlip);
     tbXFlipAttachment.reset (new ButtonAttachment (valueTreeState, "xFlip", tbXFlip));
-    tbXFlip.setColour (ToggleButton::ColourIds::tickColourId, globalLaF.ClWidgetColours[0]);
+    tbXFlip.setColour (juce::ToggleButton::ColourIds::tickColourId, globalLaF.ClWidgetColours[0]);
     tbXFlip.setButtonText ("Flip");
     tbXFlip.addListener (this);
 
     addAndMakeVisible (tbYFlip);
     tbYFlipAttachment.reset (new ButtonAttachment (valueTreeState, "yFlip", tbYFlip));
-    tbYFlip.setColour (ToggleButton::ColourIds::tickColourId, globalLaF.ClWidgetColours[1]);
+    tbYFlip.setColour (juce::ToggleButton::ColourIds::tickColourId, globalLaF.ClWidgetColours[1]);
     tbYFlip.setButtonText ("Flip");
     tbYFlip.addListener (this);
 
     addAndMakeVisible (tbZFlip);
     tbZFlipAttachment.reset (new ButtonAttachment (valueTreeState, "zFlip", tbZFlip));
-    tbZFlip.setColour (ToggleButton::ColourIds::tickColourId, globalLaF.ClWidgetColours[2]);
+    tbZFlip.setColour (juce::ToggleButton::ColourIds::tickColourId, globalLaF.ClWidgetColours[2]);
     tbZFlip.setButtonText ("Flip");
     tbZFlip.addListener (this);
 
@@ -184,17 +184,17 @@ CoordinateConverterAudioProcessorEditor::CoordinateConverterAudioProcessorEditor
     zyPlane.setZFlip (tbZFlip.getToggleState());
 
     addAndMakeVisible (slXReference);
-    slXReference.setJustificationType(Justification::centred);
+    slXReference.setJustificationType (juce::Justification::centred);
     slXReference.setEditable (true);
     slXReferenceAttachment.reset (new LabelAttachment (valueTreeState, "xReference", slXReference));
 
     addAndMakeVisible (slYReference);
-    slYReference.setJustificationType(Justification::centred);
+    slYReference.setJustificationType (juce::Justification::centred);
     slYReference.setEditable (true);
     slYReferenceAttachment.reset (new LabelAttachment (valueTreeState, "yReference", slYReference));
 
     addAndMakeVisible (slZReference);
-    slZReference.setJustificationType(Justification::centred);
+    slZReference.setJustificationType (juce::Justification::centred);
     slZReference.setEditable (true);
     slZReferenceAttachment.reset (new LabelAttachment (valueTreeState, "zReference", slZReference));
 
@@ -214,7 +214,7 @@ CoordinateConverterAudioProcessorEditor::CoordinateConverterAudioProcessorEditor
     // ============== BEGIN: RANGE SETTINGS ============
 
     addAndMakeVisible (slRadiusRange);
-    slRadiusRange.setJustificationType(Justification::centred);
+    slRadiusRange.setJustificationType (juce::Justification::centred);
     slRadiusRange.setEditable (true);
     slRadiusRangeAttachment.reset (new LabelAttachment (valueTreeState, "radiusRange", slRadiusRange));
 
@@ -222,7 +222,7 @@ CoordinateConverterAudioProcessorEditor::CoordinateConverterAudioProcessorEditor
     lbRadiusRange.setText ("Radius");
 
     addAndMakeVisible (slXRange);
-    slXRange.setJustificationType(Justification::centred);
+    slXRange.setJustificationType (juce::Justification::centred);
     slXRange.setEditable (true);
     slXRangeAttachment.reset (new LabelAttachment (valueTreeState, "xRange", slXRange));
 
@@ -230,7 +230,7 @@ CoordinateConverterAudioProcessorEditor::CoordinateConverterAudioProcessorEditor
     lbXRange.setText ("+/- X");
 
     addAndMakeVisible (slYRange);
-    slYRange.setJustificationType(Justification::centred);
+    slYRange.setJustificationType (juce::Justification::centred);
     slYRange.setEditable (true);
     slYRangeAttachment.reset (new LabelAttachment (valueTreeState, "yRange", slYRange));
 
@@ -238,7 +238,7 @@ CoordinateConverterAudioProcessorEditor::CoordinateConverterAudioProcessorEditor
     lbYRange.setText ("+/- Y");
 
     addAndMakeVisible (slZRange);
-    slZRange.setJustificationType(Justification::centred);
+    slZRange.setJustificationType (juce::Justification::centred);
     slZRange.setEditable (true);
     slZRangeAttachment.reset (new LabelAttachment (valueTreeState, "zRange", slZRange));
 
@@ -258,7 +258,7 @@ CoordinateConverterAudioProcessorEditor::~CoordinateConverterAudioProcessorEdito
 }
 
 //==============================================================================
-void CoordinateConverterAudioProcessorEditor::paint (Graphics& g)
+void CoordinateConverterAudioProcessorEditor::paint (juce::Graphics& g)
 {
     g.fillAll (globalLaF.ClBackground);
 }
@@ -276,14 +276,14 @@ void CoordinateConverterAudioProcessorEditor::resized()
 
     const int sphericalWidth = 240;
 
-    Rectangle<int> area (getLocalBounds());
+    juce::Rectangle<int> area (getLocalBounds());
 
-    Rectangle<int> footerArea (area.removeFromBottom (footerHeight));
+    juce::Rectangle<int> footerArea (area.removeFromBottom (footerHeight));
     footer.setBounds (footerArea);
 
     area.removeFromLeft (leftRightMargin);
     area.removeFromRight (leftRightMargin);
-    Rectangle<int> headerArea = area.removeFromTop (headerHeight);
+    juce::Rectangle<int> headerArea = area.removeFromTop (headerHeight);
     title.setBounds (headerArea);
     area.removeFromTop (10);
     area.removeFromBottom (5);
@@ -452,7 +452,7 @@ void CoordinateConverterAudioProcessorEditor::timerCallback()
     }
 }
 
-void CoordinateConverterAudioProcessorEditor::buttonStateChanged (Button* button)
+void CoordinateConverterAudioProcessorEditor::buttonStateChanged (juce::Button* button)
 {
     if (button == &tbXFlip)
     {
