@@ -45,12 +45,12 @@ struct Settings
 
     int xMin = hzToX (fMin);
     int xMax = hzToX (fMax);
-    int yMin = jmax (dbToY (dbMax), 0);
-    int yMax = jmax (dbToY (dbMin), yMin);
+    int yMin = juce::jmax (dbToY (dbMax), 0);
+    int yMax = juce::jmax (dbToY (dbMin), yMin);
     int yZero = dbToY (0.0f);
 
     int numPixels = xMax - xMin + 1;
-    Array<double> frequencies;
+    juce::Array<double> frequencies;
 
     const float mL = 23.0f;
     const float mR = 10.0f;
@@ -112,7 +112,7 @@ struct Settings
 
 // ============================
 
-class FilterBackdrop : public Component
+class FilterBackdrop : public juce::Component
 {
 public:
     FilterBackdrop (Settings& settings) : s (settings)
@@ -122,25 +122,25 @@ public:
 
     ~FilterBackdrop() {};
 
-    void paint (Graphics& g) override
+    void paint (juce::Graphics& g) override
     {
-        g.setColour (Colours::steelblue.withMultipliedAlpha (0.01f));
+        g.setColour (juce::Colours::steelblue.withMultipliedAlpha (0.01f));
         g.fillAll();
 
-        g.setFont (getLookAndFeel().getTypefaceForFont (Font (12.0f, 2)));
+        g.setFont (getLookAndFeel().getTypefaceForFont (juce::Font (12.0f, 2)));
         g.setFont (12.0f);
 
         // db labels
         float dyn = s.dbMax - s.dbMin;
         int numgridlines = dyn / s.gridDiv + 1;
 
-        //g.setFont (Font (getLookAndFeel().getTypefaceForFont (Font (10.0f, 1)));
-        g.setColour (Colours::white);
+        //g.setFont (juce::Font (getLookAndFeel().getTypefaceForFont (juce::Font (10.0f, 1)));
+        g.setColour (juce::Colours::white);
         int lastTextDrawPos = -1;
         for (int i = 0; i < numgridlines; ++i)
         {
             float db_val = s.dbMax - i * s.gridDiv;
-            lastTextDrawPos = drawLevelMark (g, 0, 20, db_val, String (db_val, 0), lastTextDrawPos);
+            lastTextDrawPos = drawLevelMark (g, 0, 20, db_val, juce::String (db_val, 0), lastTextDrawPos);
         }
 
 
@@ -148,35 +148,35 @@ public:
         for (float f = s.fMin; f <= s.fMax; f += pow (10, floor (log10 (f)))) {
             int xpos = s.hzToX (f);
 
-            String axislabel;
+            juce::String axislabel;
             bool drawText = false;
 
             if ((f == 20) || (f == 50) || (f == 100) || (f == 500))
             {
-                axislabel = String (f, 0);
+                axislabel = juce::String (f, 0);
                 drawText = true;
             }
             else if ((f == 1000) || (f == 5000) || (f == 10000) || (f == 20000))
             {
-                axislabel = String (f / 1000, 0);
+                axislabel = juce::String (f / 1000, 0);
                 axislabel << "k";
                 drawText = true;
             }
             else
                 continue;
 
-            g.drawText (axislabel, xpos - 10, s.dbToY (s.dbMin) + s.OH + 0.0f, 20, 12, Justification::centred, false);
+            g.drawText (axislabel, xpos - 10, s.dbToY (s.dbMin) + s.OH + 0.0f, 20, 12, juce::Justification::centred, false);
         }
 
 
-        g.setColour (Colours::steelblue.withMultipliedAlpha (0.8f));
-        g.strokePath (dbGridPath, PathStrokeType (0.5f));
+        g.setColour (juce::Colours::steelblue.withMultipliedAlpha (0.8f));
+        g.strokePath (dbGridPath, juce::PathStrokeType (0.5f));
 
-        g.setColour (Colours::steelblue.withMultipliedAlpha (0.9f));
-        g.strokePath (hzGridPathBold, PathStrokeType (1.0f));
+        g.setColour (juce::Colours::steelblue.withMultipliedAlpha (0.9f));
+        g.strokePath (hzGridPathBold, juce::PathStrokeType (1.0f));
 
-        g.setColour (Colours::steelblue.withMultipliedAlpha (0.8f));
-        g.strokePath (hzGridPath, PathStrokeType (0.5f));
+        g.setColour (juce::Colours::steelblue.withMultipliedAlpha (0.8f));
+        g.strokePath (hzGridPath, juce::PathStrokeType (0.5f));
     }
 
     void resized() override
@@ -216,7 +216,7 @@ public:
         }
     }
 
-    int inline drawLevelMark (Graphics& g, int x, int width, const int level, const String& label, int lastTextDrawPos = -1)
+    int inline drawLevelMark (juce::Graphics& g, int x, int width, const int level, const juce::String& label, int lastTextDrawPos = -1)
     {
         float yPos = s.dbToYFloat (level);
         x = x + 1.0f;
@@ -224,7 +224,7 @@ public:
 
         if (yPos - 4 > lastTextDrawPos)
         {
-            g.drawText (label, x + 2, yPos - 4, width - 4, 9, Justification::right, false);
+            g.drawText (label, x + 2, yPos - 4, width - 4, 9, juce::Justification::right, false);
             return yPos + 5;
         }
         return lastTextDrawPos;
@@ -234,33 +234,33 @@ private:
 
     Settings& s;
 
-    Path dbGridPath;
-    Path hzGridPath;
-    Path hzGridPathBold;
+    juce::Path dbGridPath;
+    juce::Path hzGridPath;
+    juce::Path hzGridPathBold;
 };
 
 
 // ============================
 
 template <typename coeffType>
-class FrequencyBand    : public Component
+class FrequencyBand    : public juce::Component
 {
 public:
     FrequencyBand (Settings& settings) : s (settings)
     {
     };
 
-    FrequencyBand (Settings& settings, typename dsp::IIR::Coefficients<coeffType>::Ptr coeffs1, typename dsp::IIR::Coefficients<coeffType>::Ptr coeffs2, Colour newColour) : s (settings), colour (newColour)
+    FrequencyBand (Settings& settings, typename juce::dsp::IIR::Coefficients<coeffType>::Ptr coeffs1, typename juce::dsp::IIR::Coefficients<coeffType>::Ptr coeffs2, juce::Colour newColour) : s (settings), colour (newColour)
     {
         addCoeffs (coeffs1, coeffs2);
     };
 
     ~FrequencyBand () {};
 
-    void paint (Graphics& g) override
+    void paint (juce::Graphics& g) override
     {
         g.setColour (colour.withMultipliedAlpha (0.7f));
-        g.strokePath (path, PathStrokeType (1.0f));
+        g.strokePath (path, juce::PathStrokeType (1.0f));
 
         g.setColour (colour.withMultipliedAlpha (0.3f));
         g.fillPath (closedPath);
@@ -295,18 +295,18 @@ public:
 
     void updateFilterResponse ()
     {
-        Array<double> tempMagnitude;
+        juce::Array<double> tempMagnitude;
         tempMagnitude.resize (s.numPixels);
         tempMagnitude.fill (1.0f);
         for (int i = 0; i < coeffs.size(); ++i)
         {
-            Array<double> filterMagnitude;
+            juce::Array<double> filterMagnitude;
             filterMagnitude.resize (s.numPixels);
             if (coeffs[i] != nullptr)
                 coeffs[i]->getMagnitudeForFrequencyArray (s.frequencies.getRawDataPointer(), filterMagnitude.getRawDataPointer(), s.numPixels, s.sampleRate);
-            FloatVectorOperations::multiply (tempMagnitude.getRawDataPointer(), filterMagnitude.getRawDataPointer(), s.numPixels);
+            juce::FloatVectorOperations::multiply (tempMagnitude.getRawDataPointer(), filterMagnitude.getRawDataPointer(), s.numPixels);
         }
-        FloatVectorOperations::copy (magnitudes.getRawDataPointer(), tempMagnitude.getRawDataPointer(), s.numPixels);
+        juce::FloatVectorOperations::copy (magnitudes.getRawDataPointer(), tempMagnitude.getRawDataPointer(), s.numPixels);
         updatePath();
     }
 
@@ -324,15 +324,15 @@ public:
             gain2 = 0.0f;
         }
 
-        float db = Decibels::gainToDecibels (magnitudes[0]) + gain1 + gain2;
-        magnitudesIncludingGains.set (0, Decibels::decibelsToGain (db) );
-        path.startNewSubPath (s.xMin, jlimit (static_cast<float> (s.yMin), static_cast<float> (s.yMax) + s.OH + 1.0f, s.dbToYFloat (db)));
+        float db = juce::Decibels::gainToDecibels (magnitudes[0]) + gain1 + gain2;
+        magnitudesIncludingGains.set (0, juce::Decibels::decibelsToGain (db) );
+        path.startNewSubPath (s.xMin, juce::jlimit (static_cast<float> (s.yMin), static_cast<float> (s.yMax) + s.OH + 1.0f, s.dbToYFloat (db)));
 
         for (int i = 1; i < s.numPixels; ++i)
         {
-            db = Decibels::gainToDecibels (magnitudes[i]) + gain1 + gain2;
-            magnitudesIncludingGains.set (i, Decibels::decibelsToGain (db) );
-            float y = jlimit (static_cast<float> (s.yMin), static_cast<float> (s.yMax) + s.OH + 1.0f, s.dbToYFloat (db));
+            db = juce::Decibels::gainToDecibels (magnitudes[i]) + gain1 + gain2;
+            magnitudesIncludingGains.set (i, juce::Decibels::decibelsToGain (db) );
+            float y = juce::jlimit (static_cast<float> (s.yMin), static_cast<float> (s.yMax) + s.OH + 1.0f, s.dbToYFloat (db));
             path.lineTo (s.xMin + i, y);
         }
 
@@ -349,12 +349,12 @@ public:
         return magnitudesIncludingGains.getRawDataPointer();
     }
 
-    Array<double> getMagnitudeIncludingGainsArray () const
+    juce::Array<double> getMagnitudeIncludingGainsArray () const
     {
         return magnitudesIncludingGains;
     }
 
-    void setColour (const Colour newColour)
+    void setColour (const juce::Colour newColour)
     {
         colour = newColour;
     }
@@ -365,7 +365,7 @@ public:
         updatePath();
     }
 
-    void addCoeffs (typename dsp::IIR::Coefficients<coeffType>::Ptr coeffs1, typename dsp::IIR::Coefficients<coeffType>::Ptr coeffs2)
+    void addCoeffs (typename juce::dsp::IIR::Coefficients<coeffType>::Ptr coeffs1, typename juce::dsp::IIR::Coefficients<coeffType>::Ptr coeffs2)
     {
         coeffs.add (coeffs1);
         coeffs.add (coeffs2);
@@ -373,15 +373,15 @@ public:
 
 private:
     Settings& s;
-    Array<typename dsp::IIR::Coefficients<coeffType>::Ptr> coeffs;
+    juce::Array<typename juce::dsp::IIR::Coefficients<coeffType>::Ptr> coeffs;
 
-    Colour colour;
+    juce::Colour colour;
     bool bypassed {false};
 
     float makeUp = 0.0f, gainReduction = 0.0f;
 
-    Array<double> magnitudes, magnitudesIncludingGains;
-    Path path, closedPath;
+    juce::Array<double> magnitudes, magnitudesIncludingGains;
+    juce::Path path, closedPath;
 
     JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (FrequencyBand);
 };
@@ -389,7 +389,7 @@ private:
 // ============================
 
 template <typename coefficientType>
-class OverallMagnitude  : public Component
+class OverallMagnitude  : public juce::Component
 {
 public:
     OverallMagnitude (Settings& settings, int numFreqBands) : s (settings), numBands (numFreqBands), overallGain (0.0f)
@@ -398,12 +398,12 @@ public:
 
     ~OverallMagnitude () {};
 
-    void paint (Graphics& g) override
+    void paint (juce::Graphics& g) override
     {
-        g.setColour (Colours::white);
-        g.strokePath (path, PathStrokeType (1.25f));
+        g.setColour (juce::Colours::white);
+        g.strokePath (path, juce::PathStrokeType (1.25f));
 
-        g.setColour (Colours::white.withMultipliedAlpha (0.125f));
+        g.setColour (juce::Colours::white.withMultipliedAlpha (0.125f));
         g.fillPath (closedPath);
     }
 
@@ -423,7 +423,7 @@ public:
         overallMagnitude.fill (overallGain);
         for (int i = 0; i < (*freqBands).size(); ++i)
         {
-            FloatVectorOperations::add (overallMagnitude.getRawDataPointer(), (*freqBands)[i]->getMagnitudeIncludingGains (), s.numPixels);
+            juce::FloatVectorOperations::add (overallMagnitude.getRawDataPointer(), (*freqBands)[i]->getMagnitudeIncludingGains (), s.numPixels);
         }
 
         updatePath();
@@ -435,13 +435,13 @@ public:
         path.clear();
         closedPath.clear();
 
-        float db = Decibels::gainToDecibels (overallMagnitude[0]);
-        path.startNewSubPath (s.xMin, jlimit (static_cast<float> (s.yMin), static_cast<float> (s.yMax) + s.OH + 1.0f, s.dbToYFloat (db)));
+        float db = juce::Decibels::gainToDecibels (overallMagnitude[0]);
+        path.startNewSubPath (s.xMin, juce::jlimit (static_cast<float> (s.yMin), static_cast<float> (s.yMax) + s.OH + 1.0f, s.dbToYFloat (db)));
 
         for (int i = 1; i < s.numPixels; ++i)
         {
-            db = Decibels::gainToDecibels (overallMagnitude[i]);
-            float y = jlimit (static_cast<float> (s.yMin), static_cast<float> (s.yMax) + s.OH + 1.0f, s.dbToYFloat (db));
+            db = juce::Decibels::gainToDecibels (overallMagnitude[i]);
+            float y = juce::jlimit (static_cast<float> (s.yMin), static_cast<float> (s.yMax) + s.OH + 1.0f, s.dbToYFloat (db));
             path.lineTo (s.xMin + i, y);
         }
         closedPath = path;
@@ -453,17 +453,17 @@ public:
         repaint();
     }
 
-    void setFreqBands (OwnedArray<FrequencyBand<coefficientType>>* bandsForOverallGain)
+    void setFreqBands (juce::OwnedArray<FrequencyBand<coefficientType>>* bandsForOverallGain)
     {
         freqBands = bandsForOverallGain;
     }
 
 private:
     Settings& s;
-    OwnedArray<FrequencyBand<coefficientType>>* freqBands;
+    juce::OwnedArray<FrequencyBand<coefficientType>>* freqBands;
 
-    Array<double> overallMagnitude;
-    Path path, closedPath;
+    juce::Array<double> overallMagnitude;
+    juce::Path path, closedPath;
 
     int numBands;
     float overallGain;
@@ -473,7 +473,7 @@ private:
 // ============================
 
 template <typename T>
-class FilterBankVisualizer : public Component
+class FilterBankVisualizer : public juce::Component
 {
 public:
     FilterBankVisualizer (float fMin, float fMax, float dbMin, float dbMax, float gridDiv, double& sampleRate, int numBands, bool overallMagnitude=false) : s {fMin, fMax, dbMin, dbMax, gridDiv, sampleRate}, filterBackdrop (s), overallMagnitude (s, numBands), numFreqBands (numBands), displayOverallMagnitude (overallMagnitude)
@@ -509,8 +509,8 @@ public:
 
         s.xMin = s.hzToX (s.fMin);
         s.xMax = s.hzToX (s.fMax);
-        s.yMin = jmax (s.dbToY (s.dbMax), 0);
-        s.yMax = jmax (s.dbToY (s.dbMin), s.yMin);
+        s.yMin = juce::jmax (s.dbToY (s.dbMax), 0);
+        s.yMax = juce::jmax (s.dbToY (s.dbMin), s.yMin);
         s.yZero = s.dbToY (0.0f);
 
         s.numPixels = s.xMax - s.xMin + 1;
@@ -520,13 +520,13 @@ public:
             s.frequencies.set (i, s.xToHz (s.xMin + i));
     }
 
-    void paint (Graphics& g) override
+    void paint (juce::Graphics& g) override
     {
     }
 
-    void paintOverChildren (Graphics& g) override
+    void paintOverChildren (juce::Graphics& g) override
     {
-        g.excludeClipRegion (Rectangle<int> (0.0f, s.yMax + s.OH, s.width, s.height - s.yMax - s.OH));
+        g.excludeClipRegion (juce::Rectangle<int> (0.0f, s.yMax + s.OH, s.width, s.height - s.yMax - s.OH));
 
         // draw crossovers separators and knobs
         float yPos = s.dbToYFloat (0.0f);
@@ -534,14 +534,14 @@ public:
         for (int i = 0; i < crossoverSliders.size(); ++i)
         {
             float xPos = crossoverSliders[i] == nullptr ? s.xMin : s.hzToX (crossoverSliders[i]->getValue());
-            Line<float> freqBandSeparator;
+            juce::Line<float> freqBandSeparator;
             freqBandSeparator.setStart (xPos, s.yMin);
             freqBandSeparator.setEnd (xPos, s.yMax + s.yMin);
             g.setColour (activeElem == i ? colour.brighter() : colour.withMultipliedAlpha (0.8));
             g.drawLine (freqBandSeparator, i == activeElem ? 2.5f : 2.0f);
             prevXPos = xPos;
 
-            g.setColour (Colours::black);
+            g.setColour (juce::Colours::black);
             g.drawEllipse (xPos - 5.0f, yPos - 5.0f , 10.0f, 10.0f, 3.0f);
             g.setColour (activeElem == i ? colour.brighter() : colour);
             g.fillEllipse (xPos - 5.0f, yPos - 5.0f , 10.0f, 10.0f);
@@ -553,7 +553,7 @@ public:
     {
         updateSettings ();
 
-        Rectangle<int> area = getLocalBounds();
+        juce::Rectangle<int> area = getLocalBounds();
         filterBackdrop.setBounds (area);
         for (int i = 0; i < freqBands.size(); ++i)
         {
@@ -574,9 +574,9 @@ public:
         numFreqBands = newValue;
     }
 
-    void mouseDrag (const MouseEvent &event) override
+    void mouseDrag (const juce::MouseEvent &event) override
     {
-        Point<int> pos = event.getPosition();
+        juce::Point<int> pos = event.getPosition();
         float frequency = s.xToHz (pos.x);
 
         if (activeElem != -1)
@@ -590,9 +590,9 @@ public:
         }
     }
 
-    void mouseMove (const MouseEvent &event) override
+    void mouseMove (const juce::MouseEvent &event) override
     {
-        Point<int> pos = event.getPosition();
+        juce::Point<int> pos = event.getPosition();
         int oldActiveElem = activeElem;
         activeElem = -1;
 
@@ -600,7 +600,7 @@ public:
         {
             int x = crossoverSliders[i] == nullptr ? s.hzToX (s.fMin) : s.hzToX (crossoverSliders[i]->getValue());
             float y = s.dbToYFloat (0.0f);
-            Point<int> filterPos (x, y);
+            juce::Point<int> filterPos (x, y);
 
             if (pos.getDistanceSquaredFrom (filterPos) < 48)
             {
@@ -655,7 +655,7 @@ public:
 
         for (int i = 0; i < numFreqBands; ++i)
         {
-            Colour colour = freqBandColours[i];
+            juce::Colour colour = freqBandColours[i];
 
             if (! soloSet.empty())
             {
@@ -668,7 +668,7 @@ public:
         }
     }
 
-    void setFrequencyBand (const int i, typename dsp::IIR::Coefficients<T>::Ptr coeffs1, typename  dsp::IIR::Coefficients<T>::Ptr coeffs2, Colour colour)
+    void setFrequencyBand (const int i, typename juce::dsp::IIR::Coefficients<T>::Ptr coeffs1, typename  juce::dsp::IIR::Coefficients<T>::Ptr coeffs2, juce::Colour colour)
     {
         freqBands[i]->addCoeffs (coeffs1, coeffs2);
         freqBands[i]->setColour (colour);
@@ -677,7 +677,7 @@ public:
         freqBandColours.set (i, colour);
     }
 
-    void addFrequencyBand (typename dsp::IIR::Coefficients<T>::Ptr coeffs1, typename dsp::IIR::Coefficients<T>::Ptr coeffs2, Colour colour)
+    void addFrequencyBand (typename juce::dsp::IIR::Coefficients<T>::Ptr coeffs1, typename juce::dsp::IIR::Coefficients<T>::Ptr coeffs2, juce::Colour colour)
     {
         freqBands.add (new FrequencyBand<T> (s, coeffs1, coeffs2, colour));
         addAndMakeVisible (freqBands.getLast());
@@ -710,7 +710,7 @@ public:
         overallMagnitude.setOverallGain (gain);
     }
 
-    void addCrossover (Slider* crossoverSlider = nullptr)
+    void addCrossover (juce::Slider* crossoverSlider = nullptr)
     {
         crossoverSliders.add (crossoverSlider);
     }
@@ -720,16 +720,16 @@ private:
     Settings s;
 
     FilterBackdrop filterBackdrop;
-    OwnedArray<FrequencyBand<T>> freqBands;
+    juce::OwnedArray<FrequencyBand<T>> freqBands;
     OverallMagnitude<T> overallMagnitude;
 
-    Array<Slider*> crossoverSliders;
+    juce::Array<juce::Slider*> crossoverSliders;
 
     int numFreqBands, activeElem {-1};
     bool displayOverallMagnitude {false};
 
-    Colour colour {0xFFD8D8D8};
-    Array<Colour> freqBandColours;
+    juce::Colour colour {0xFFD8D8D8};
+    juce::Array<juce::Colour> freqBandColours;
 
     std::set<int> soloSet;
 
