@@ -24,8 +24,8 @@
 
 
 //==============================================================================
-MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor (MultiBandCompressorAudioProcessor& p, AudioProcessorValueTreeState& vts)
-    : AudioProcessorEditor (&p), processor (p), valueTreeState (vts), footer (p.getOSCParameterInterface()), filterBankVisualizer (20.0f, 20000.0f, -15.0f, 20.0f, 5.0f, p.getSampleRate(), numFreqBands)
+MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor (MultiBandCompressorAudioProcessor& p, juce::AudioProcessorValueTreeState& vts)
+    : juce::AudioProcessorEditor (&p), processor (p), valueTreeState (vts), footer (p.getOSCParameterInterface()), filterBankVisualizer (20.0f, 20000.0f, -15.0f, 20.0f, 5.0f, p.getSampleRate(), numFreqBands)
 {
     // ============== BEGIN: essentials ======================
     // set GUI size and lookAndFeel
@@ -34,7 +34,7 @@ MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor
 
     // make title and footer visible, and set the PluginName
     addAndMakeVisible (&title);
-    title.setTitle (String ("MultiBand"), String ("Compressor"));
+    title.setTitle (juce::String ("MultiBand"), juce::String ("Compressor"));
     title.setFont (globalLaF.robotoBold, globalLaF.robotoLight);
     addAndMakeVisible (&footer);
     // ============= END: essentials ========================
@@ -46,12 +46,12 @@ MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor
     tooltips.setOpaque (false);
 
 
-    const Colour colours[numFreqBands] =
+    const juce::Colour colours[numFreqBands] =
     {
-        Colours::cornflowerblue,
-        Colours::greenyellow,
-        Colours::yellow,
-        Colours::orangered
+        juce::Colours::cornflowerblue,
+        juce::Colours::greenyellow,
+        juce::Colours::yellow,
+        juce::Colours::orangered
     };
 
 
@@ -66,52 +66,52 @@ MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor
         // ===== GR METERS =====
         addAndMakeVisible (&GRmeter[i]);
         GRmeter[i].setMinLevel (-25.0f);
-        GRmeter[i].setColour (Colours::red.withMultipliedAlpha (0.8f));
+        GRmeter[i].setColour (juce::Colours::red.withMultipliedAlpha (0.8f));
         GRmeter[i].setGainReductionMeter (true);
 
 
         // ==== SLIDERS ====
         addAndMakeVisible (&slThreshold[i]);
-        slThresholdAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "threshold" + String (i), slThreshold[i]);
-        slThreshold[i].setSliderStyle (Slider::RotaryHorizontalVerticalDrag);
-        slThreshold[i].setTextBoxStyle (Slider::TextBoxBelow, false, 50, 12);
-        slThreshold[i].setColour (Slider::rotarySliderOutlineColourId, colours[i]);
+        slThresholdAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "threshold" + juce::String (i), slThreshold[i]);
+        slThreshold[i].setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
+        slThreshold[i].setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 12);
+        slThreshold[i].setColour (juce::Slider::rotarySliderOutlineColourId, colours[i]);
         slThreshold[i].setTextValueSuffix (" dB");
 
         addAndMakeVisible (&slKnee[i]);
-        slKneeAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "knee" + String (i), slKnee[i]);
-        slKnee[i].setSliderStyle (Slider::RotaryHorizontalVerticalDrag);
-        slKnee[i].setTextBoxStyle (Slider::TextBoxBelow, false, 50, 12);
-        slKnee[i].setColour (Slider::rotarySliderOutlineColourId, colours[i]);
+        slKneeAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "knee" + juce::String (i), slKnee[i]);
+        slKnee[i].setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
+        slKnee[i].setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 12);
+        slKnee[i].setColour (juce::Slider::rotarySliderOutlineColourId, colours[i]);
         slKnee[i].setTextValueSuffix (" dB");
 
         addAndMakeVisible (&slRatio[i]);
-        slRatioAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "ratio" + String (i), slRatio[i]);
-        slRatio[i].setSliderStyle (Slider::RotaryHorizontalVerticalDrag);
-        slRatio[i].setTextBoxStyle (Slider::TextBoxBelow, false, 50, 12);
-        slRatio[i].setColour (Slider::rotarySliderOutlineColourId, colours[i]);
+        slRatioAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "ratio" + juce::String (i), slRatio[i]);
+        slRatio[i].setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
+        slRatio[i].setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 12);
+        slRatio[i].setColour (juce::Slider::rotarySliderOutlineColourId, colours[i]);
 
         addAndMakeVisible (&slAttackTime[i]);
-        slAttackTimeAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "attack" + String (i), slAttackTime[i]);
-        slAttackTime[i].setSliderStyle (Slider::RotaryHorizontalVerticalDrag);
-        slAttackTime[i].setTextBoxStyle (Slider::TextBoxBelow, false, 50, 12);
-        slAttackTime[i].setColour (Slider::rotarySliderOutlineColourId, colours[i]);
+        slAttackTimeAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "attack" + juce::String (i), slAttackTime[i]);
+        slAttackTime[i].setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
+        slAttackTime[i].setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 12);
+        slAttackTime[i].setColour (juce::Slider::rotarySliderOutlineColourId, colours[i]);
         slRatio[i].setTextValueSuffix (" ms");
 
         addAndMakeVisible (&slReleaseTime[i]);
-        slReleaseTimeAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "release" + String (i), slReleaseTime[i]);
-        slReleaseTime[i].setSliderStyle (Slider::RotaryHorizontalVerticalDrag);
-        slReleaseTime[i].setTextBoxStyle (Slider::TextBoxBelow, false, 50, 12);
-        slReleaseTime[i].setColour (Slider::rotarySliderOutlineColourId, colours[i]);
+        slReleaseTimeAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "release" + juce::String (i), slReleaseTime[i]);
+        slReleaseTime[i].setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
+        slReleaseTime[i].setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 12);
+        slReleaseTime[i].setColour (juce::Slider::rotarySliderOutlineColourId, colours[i]);
         slReleaseTime[i].setTextValueSuffix (" ms");
 
         addAndMakeVisible (&slMakeUpGain[i]);
-        slMakeUpGainAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "makeUpGain" + String (i), slMakeUpGain[i]);
-        slMakeUpGain[i].setSliderStyle (Slider::RotaryHorizontalVerticalDrag);
-        slMakeUpGain[i].setTextBoxStyle (Slider::TextBoxBelow, false, 50, 12);
-        slMakeUpGain[i].setColour (Slider::rotarySliderOutlineColourId, colours[i]);
+        slMakeUpGainAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "makeUpGain" + juce::String (i), slMakeUpGain[i]);
+        slMakeUpGain[i].setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
+        slMakeUpGain[i].setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 12);
+        slMakeUpGain[i].setColour (juce::Slider::rotarySliderOutlineColourId, colours[i]);
         slMakeUpGain[i].setTextValueSuffix (" dB");
-        slMakeUpGain[i].setName (String ("MakeUpGain" + String (i)));
+        slMakeUpGain[i].setName (juce::String ("MakeUpGain" + juce::String (i)));
         slMakeUpGain[i].addListener (this);
 
 
@@ -142,22 +142,22 @@ MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor
 
 
         // ==== BUTTONS ====
-        tbSolo[i].setColour (ToggleButton::tickColourId, Colour (0xFFFFFF66).withMultipliedAlpha (0.85f));
+        tbSolo[i].setColour (juce::ToggleButton::tickColourId, juce::Colour (0xFFFFFF66).withMultipliedAlpha (0.85f));
         tbSolo[i].setScaleFontSize (0.75f);
         tbSolo[i].setButtonText ("S");
-        tbSolo[i].setName ("solo" + String (i));
-        tbSolo[i].setTooltip ("Solo band #" + String (i));
-        soloAttachment[i]  = std::make_unique<AudioProcessorValueTreeState::ButtonAttachment> (valueTreeState, "solo" + String (i), tbSolo[i]);
+        tbSolo[i].setName ("solo" + juce::String (i));
+        tbSolo[i].setTooltip ("Solo band #" + juce::String (i));
+        soloAttachment[i]  = std::make_unique<juce::AudioProcessorValueTreeState::ButtonAttachment> (valueTreeState, "solo" + juce::String (i), tbSolo[i]);
         tbSolo[i].setClickingTogglesState (true);
         tbSolo[i].addListener (this);
         addAndMakeVisible (&tbSolo[i]);
 
-        tbBypass[i].setColour (ToggleButton::tickColourId, Colour (0xFF5bAE87).withMultipliedAlpha (0.85f));
+        tbBypass[i].setColour (juce::ToggleButton::tickColourId, juce::Colour (0xFF5bAE87).withMultipliedAlpha (0.85f));
         tbBypass[i].setScaleFontSize (0.75f);
         tbBypass[i].setButtonText ("B");
-        tbBypass[i].setName ("bypass" + String (i));
-        tbBypass[i].setTooltip ("Bypass band #" + String (i));
-        bypassAttachment[i] = std::make_unique<AudioProcessorValueTreeState::ButtonAttachment> (valueTreeState, "bypass" + String (i), tbBypass[i]);
+        tbBypass[i].setName ("bypass" + juce::String (i));
+        tbBypass[i].setTooltip ("Bypass band #" + juce::String (i));
+        bypassAttachment[i] = std::make_unique<juce::AudioProcessorValueTreeState::ButtonAttachment> (valueTreeState, "bypass" + juce::String (i), tbBypass[i]);
         tbBypass[i].setClickingTogglesState (true);
         tbBypass[i].addListener (this);
         addAndMakeVisible (&tbBypass[i]);
@@ -165,8 +165,8 @@ MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor
 
 
     // ==== FILTER VISUALIZATION ====
-    dsp::IIR::Coefficients<double>::Ptr coeffs1;
-    dsp::IIR::Coefficients<double>::Ptr coeffs2;
+    juce::dsp::IIR::Coefficients<double>::Ptr coeffs1;
+    juce::dsp::IIR::Coefficients<double>::Ptr coeffs2;
     for (int i = 0; i < numFreqBands; ++i)
     {
         switch (i)
@@ -199,7 +199,7 @@ MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor
 
 
     // SHOW OVERALL MAGNITUDE BUTTON
-    tbOverallMagnitude.setColour (ToggleButton::tickColourId, Colours::white);
+    tbOverallMagnitude.setColour (juce::ToggleButton::tickColourId, juce::Colours::white);
     tbOverallMagnitude.setButtonText ("show total magnitude");
     tbOverallMagnitude.setName ("overallMagnitude");
     tbOverallMagnitude.setClickingTogglesState (true);
@@ -210,13 +210,13 @@ MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor
     // ==== CROSSOVER SLIDERS ====
     for (int i = 0; i < numFreqBands-1; ++i)
     {
-        slCrossoverAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "crossover" + String (i), slCrossover[i]);
+        slCrossoverAttachment[i] = std::make_unique<SliderAttachment> (valueTreeState, "crossover" + juce::String (i), slCrossover[i]);
         addAndMakeVisible (&slCrossover[i]);
-        slCrossover[i].setSliderStyle (Slider::RotaryHorizontalVerticalDrag);
-        slCrossover[i].setTextBoxStyle (Slider::TextBoxBelow, false, 50, 12);
-        slCrossover[i].setColour (Slider::rotarySliderOutlineColourId, globalLaF.ClRotSliderArrow);
-        slCrossover[i].setTooltip ("Crossover Frequency " + String (i+1));
-        slCrossover[i].setName ("Crossover" + String (i));
+        slCrossover[i].setSliderStyle (juce::Slider::RotaryHorizontalVerticalDrag);
+        slCrossover[i].setTextBoxStyle (juce::Slider::TextBoxBelow, false, 50, 12);
+        slCrossover[i].setColour (juce::Slider::rotarySliderOutlineColourId, globalLaF.ClRotSliderArrow);
+        slCrossover[i].setTooltip ("Crossover Frequency " + juce::String (i+1));
+        slCrossover[i].setName ("Crossover" + juce::String (i));
         slCrossover[i].addListener (this);
 
         // add crossover to visualizer
@@ -227,7 +227,7 @@ MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor
     // ==== METERS - INPUT/OUTPUT ====
     addAndMakeVisible (&omniInputMeter);
     omniInputMeter.setMinLevel (-60.0f);
-    omniInputMeter.setColour (Colours::green.withMultipliedAlpha (0.8f));
+    omniInputMeter.setColour (juce::Colours::green.withMultipliedAlpha (0.8f));
     omniInputMeter.setGainReductionMeter (false);
     addAndMakeVisible (&lbInput);
     lbInput.setText ("Input");
@@ -235,7 +235,7 @@ MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor
 
     addAndMakeVisible (&omniOutputMeter);
     omniOutputMeter.setMinLevel (-60.0f);
-    omniOutputMeter.setColour (Colours::green.withMultipliedAlpha (0.8f));
+    omniOutputMeter.setColour (juce::Colours::green.withMultipliedAlpha (0.8f));
     omniOutputMeter.setGainReductionMeter (false);
     addAndMakeVisible (&lbOutput);
     lbOutput.setText ("Output");
@@ -295,7 +295,7 @@ MultiBandCompressorAudioProcessorEditor::MultiBandCompressorAudioProcessorEditor
 
 
     /* resized () is called here, because otherwise the compressorVisualizers won't be drawn to the GUI until one manually resizes the window.
-    It seems resized() somehow gets called *before* the constructor and therefore OwnedArray<CompressorVisualizers> is still empty on the first resized call... */
+    It seems resized() somehow gets called *before* the constructor and therefore juce::OwnedArray<CompressorVisualizers> is still empty on the first resized call... */
     resized ();
 
     // start timer after everything is set up properly
@@ -308,7 +308,7 @@ MultiBandCompressorAudioProcessorEditor::~MultiBandCompressorAudioProcessorEdito
 }
 
 //==============================================================================
-void MultiBandCompressorAudioProcessorEditor::paint (Graphics& g)
+void MultiBandCompressorAudioProcessorEditor::paint (juce::Graphics& g)
 {
     g.fillAll (globalLaF.ClBackground);
 
@@ -320,14 +320,14 @@ void MultiBandCompressorAudioProcessorEditor::resized()
     const int leftRightMargin = 30;
     const int headerHeight = 60;
     const int footerHeight = 25;
-    Rectangle<int> area (getLocalBounds());
+    juce::Rectangle<int> area (getLocalBounds());
 
-    Rectangle<int> footerArea (area.removeFromBottom (footerHeight));
+    juce::Rectangle<int> footerArea (area.removeFromBottom (footerHeight));
     footer.setBounds (footerArea);
 
     area.removeFromLeft (leftRightMargin);
     area.removeFromRight (leftRightMargin);
-    Rectangle<int> headerArea = area.removeFromTop (headerHeight);
+    juce::Rectangle<int> headerArea = area.removeFromTop (headerHeight);
     title.setBounds (headerArea);
     area.removeFromTop (10);
     area.removeFromBottom (5);
@@ -343,19 +343,19 @@ void MultiBandCompressorAudioProcessorEditor::resized()
     const int compressorToCrossoverAndButtonGap = 2;
 
     // split
-//    Rectangle<int> leftArea = area.removeFromLeft (area.proportionOfWidth (leftToRightRatio));
-//    Rectangle<int> rightArea (area);
+//    juce::Rectangle<int> leftArea = area.removeFromLeft (area.proportionOfWidth (leftToRightRatio));
+//    juce::Rectangle<int> rightArea (area);
 
-    Rectangle<int> rightArea = area.removeFromRight (130);
+    juce::Rectangle<int> rightArea = area.removeFromRight (130);
     area.removeFromRight (leftToRightGap);
-    Rectangle<int> leftArea (area);
+    juce::Rectangle<int> leftArea (area);
 
 
 //    leftArea.removeFromRight (leftToRightGap / 2);
 //    rightArea.removeFromLeft (leftToRightGap / 2);
-    Rectangle<int> filterBankArea = leftArea.removeFromTop (leftArea.proportionOfHeight (filterBankToLowerRatio));
-    Rectangle<int> compressorArea = leftArea;
-    Rectangle<int> crossoverAndButtonArea = compressorArea.removeFromTop (compressorArea.proportionOfHeight (crossoverAndButtonToCompressorsRatio));
+    juce::Rectangle<int> filterBankArea = leftArea.removeFromTop (leftArea.proportionOfHeight (filterBankToLowerRatio));
+    juce::Rectangle<int> compressorArea = leftArea;
+    juce::Rectangle<int> crossoverAndButtonArea = compressorArea.removeFromTop (compressorArea.proportionOfHeight (crossoverAndButtonToCompressorsRatio));
 
     // safeguard against haphephobia
     filterBankArea.removeFromBottom (filterToCrossoverAndButtonGap / 2);
@@ -374,9 +374,9 @@ void MultiBandCompressorAudioProcessorEditor::resized()
     const float crossoverToButtonsRatio = 0.85f;
     const float trimButtonsHeight = 0.17f;
     const float trimButtonsWidth = 0.17f;
-    Rectangle<int> soloButtonArea;
-    Rectangle<int> bypassButtonArea;
-    Rectangle<int> crossoverArea;
+    juce::Rectangle<int> soloButtonArea;
+    juce::Rectangle<int> bypassButtonArea;
+    juce::Rectangle<int> crossoverArea;
 
     const int buttonsWidth = crossoverAndButtonArea.getWidth () / (numFreqBands + (numFreqBands-1)*crossoverToButtonsRatio);
     const int crossoverSliderWidth = buttonsWidth * crossoverToButtonsRatio;
@@ -384,7 +384,7 @@ void MultiBandCompressorAudioProcessorEditor::resized()
 
     for (int i = 0; i < numFreqBands; ++i)
     {
-        // Buttons
+        // juce::Buttons
         bypassButtonArea = crossoverAndButtonArea.removeFromLeft (buttonsWidth);
         bypassButtonArea.reduce (crossoverToButtonGap / 2, 0);
         soloButtonArea = bypassButtonArea.removeFromLeft (bypassButtonArea.proportionOfWidth (0.5));
@@ -393,7 +393,7 @@ void MultiBandCompressorAudioProcessorEditor::resized()
         tbSolo[i].setBounds (soloButtonArea.reduced (soloButtonArea.proportionOfWidth (trimButtonsWidth), soloButtonArea.proportionOfHeight (trimButtonsHeight)));
         tbBypass[i].setBounds  (bypassButtonArea.reduced (bypassButtonArea.proportionOfWidth (trimButtonsWidth), bypassButtonArea.proportionOfHeight (trimButtonsHeight)));
 
-        // Sliders
+        // juce::Sliders
         if (i < numFreqBands - 1)
         {
             crossoverArea = crossoverAndButtonArea.removeFromLeft (crossoverSliderWidth);
@@ -413,7 +413,7 @@ void MultiBandCompressorAudioProcessorEditor::resized()
 
     compressorArea.reduce (((compressorArea.getWidth() - (numFreqBands-1) * bandToBandGap) % numFreqBands) / 2, 0);
     const int widthPerBand = ((compressorArea.getWidth() - (numFreqBands-1) * bandToBandGap) / numFreqBands);
-    Rectangle<int> characteristicArea, paramArea, paramRow1, paramRow2, labelRow1, labelRow2, grMeterArea;
+    juce::Rectangle<int> characteristicArea, paramArea, paramRow1, paramRow2, labelRow1, labelRow2, grMeterArea;
 
     for (int i = 0; i < numFreqBands; ++i)
     {
@@ -467,14 +467,14 @@ void MultiBandCompressorAudioProcessorEditor::resized()
     const float labelToMeterRatio = 0.1f;
     const int meterToMeterGap = 10;
 
-    Rectangle<int> meterArea = rightArea.removeFromTop (rightArea.proportionOfHeight (filterBankToLowerRatio));
+    juce::Rectangle<int> meterArea = rightArea.removeFromTop (rightArea.proportionOfHeight (filterBankToLowerRatio));
     meterArea.reduce (meterArea.proportionOfWidth (0.18f), 0);
-    Rectangle<int> inputMeterArea = meterArea.removeFromLeft (meterArea.proportionOfWidth (0.5f));
-    Rectangle<int> outputMeterArea = meterArea;
+    juce::Rectangle<int> inputMeterArea = meterArea.removeFromLeft (meterArea.proportionOfWidth (0.5f));
+    juce::Rectangle<int> outputMeterArea = meterArea;
     inputMeterArea.removeFromRight (meterToMeterGap / 2);
     outputMeterArea.removeFromLeft (meterToMeterGap / 2);
-    Rectangle<int> inputMeterLabelArea = inputMeterArea.removeFromBottom (inputMeterArea.proportionOfHeight (labelToMeterRatio));
-    Rectangle<int> outputMeterLabelArea = outputMeterArea.removeFromBottom (outputMeterArea.proportionOfHeight (labelToMeterRatio));
+    juce::Rectangle<int> inputMeterLabelArea = inputMeterArea.removeFromBottom (inputMeterArea.proportionOfHeight (labelToMeterRatio));
+    juce::Rectangle<int> outputMeterLabelArea = outputMeterArea.removeFromBottom (outputMeterArea.proportionOfHeight (labelToMeterRatio));
 
     omniInputMeter.setBounds (inputMeterArea);
     omniOutputMeter.setBounds (outputMeterArea);
@@ -490,14 +490,14 @@ void MultiBandCompressorAudioProcessorEditor::resized()
     const float trimSliderWidth = 0.00f;
     const int masterToCompressorSectionGap = 18;
 
-    Rectangle<int> masterArea = rightArea.removeFromBottom (rightArea.proportionOfHeight (masterToUpperArea));
+    juce::Rectangle<int> masterArea = rightArea.removeFromBottom (rightArea.proportionOfHeight (masterToUpperArea));
     masterArea.removeFromLeft (masterToCompressorSectionGap);
     gcMasterControls.setBounds (masterArea);
     masterArea.removeFromTop (trimFromGroupComponentHeader);
 
-    Rectangle<int> sliderRow = masterArea.removeFromTop (masterArea.proportionOfHeight (0.5f));
+    juce::Rectangle<int> sliderRow = masterArea.removeFromTop (masterArea.proportionOfHeight (0.5f));
 //    sliderRow.reduce (sliderRow.proportionOfWidth (trimSliderWidth), sliderRow.proportionOfHeight (trimSliderHeight));
-    Rectangle<int> labelRow = sliderRow.removeFromBottom (sliderRow.proportionOfHeight (labelToSliderRatio));
+    juce::Rectangle<int> labelRow = sliderRow.removeFromBottom (sliderRow.proportionOfHeight (labelToSliderRatio));
 
     const int masterSliderWidth = 35;
     DBG (sliderRow.getWidth());
@@ -527,13 +527,13 @@ void MultiBandCompressorAudioProcessorEditor::resized()
 
     rightArea.removeFromLeft (trimFromLeft);
     rightArea.reduce (0, rightArea.proportionOfHeight (trimHeight));
-    Rectangle<int> totalMagnitudeButtonArea = rightArea.removeFromTop (rightArea.proportionOfHeight (0.5));
+    juce::Rectangle<int> totalMagnitudeButtonArea = rightArea.removeFromTop (rightArea.proportionOfHeight (0.5));
     tbOverallMagnitude.setBounds (totalMagnitudeButtonArea);
 
 }
 
 
-void MultiBandCompressorAudioProcessorEditor::sliderValueChanged (Slider *slider)
+void MultiBandCompressorAudioProcessorEditor::sliderValueChanged (juce::Slider *slider)
 {
     if (slider->getName().startsWith ("MakeUpGain"))
     {
@@ -542,7 +542,7 @@ void MultiBandCompressorAudioProcessorEditor::sliderValueChanged (Slider *slider
     }
 }
 
-void MultiBandCompressorAudioProcessorEditor::buttonClicked (Button* button)
+void MultiBandCompressorAudioProcessorEditor::buttonClicked (juce::Button* button)
 {
 
     if (button->getName().startsWith ("bypass"))
