@@ -34,9 +34,9 @@ MultiEQAudioProcessor::MultiEQAudioProcessor()
                            BusesProperties()
                      #if ! JucePlugin_IsMidiEffect
                       #if ! JucePlugin_IsSynth
-                       .withInput  ("Input",  AudioChannelSet::discreteChannels (64), true)
+                       .withInput  ("Input",  juce::AudioChannelSet::discreteChannels (64), true)
                       #endif
-                       .withOutput ("Output", AudioChannelSet::discreteChannels (64), true)
+                       .withOutput ("Output", juce::AudioChannelSet::discreteChannels (64), true)
                      #endif
                        ,
 #endif
@@ -50,16 +50,16 @@ createParameterLayout())
 
     for (int i = 0; i < numFilterBands; ++i)
     {
-        filterEnabled[i] = parameters.getRawParameterValue ("filterEnabled" + String(i));
-        filterType[i] = parameters.getRawParameterValue ("filterType" + String(i));
-        filterFrequency[i] = parameters.getRawParameterValue ("filterFrequency" + String(i));
-        filterQ[i] = parameters.getRawParameterValue ("filterQ" + String(i));
-        filterGain[i] = parameters.getRawParameterValue ("filterGain" + String(i));
+        filterEnabled[i] = parameters.getRawParameterValue ("filterEnabled" + juce::String(i));
+        filterType[i] = parameters.getRawParameterValue ("filterType" + juce::String(i));
+        filterFrequency[i] = parameters.getRawParameterValue ("filterFrequency" + juce::String(i));
+        filterQ[i] = parameters.getRawParameterValue ("filterQ" + juce::String(i));
+        filterGain[i] = parameters.getRawParameterValue ("filterGain" + juce::String(i));
 
-        parameters.addParameterListener("filterType" + String(i), this);
-        parameters.addParameterListener("filterFrequency" + String(i), this);
-        parameters.addParameterListener("filterQ" + String(i), this);
-        parameters.addParameterListener("filterGain" + String(i), this);
+        parameters.addParameterListener("filterType" + juce::String(i), this);
+        parameters.addParameterListener("filterFrequency" + juce::String(i), this);
+        parameters.addParameterListener("filterQ" + juce::String(i), this);
+        parameters.addParameterListener("filterGain" + juce::String(i), this);
     }
 
     additionalTempCoefficients[0] = IIR::Coefficients<float>::makeAllPass (48000.0, 20.0f);
@@ -107,7 +107,7 @@ void MultiEQAudioProcessor::updateGuiCoefficients()
     const double sampleRate = getSampleRate() == 0 ? 48000.0 : getSampleRate();
 
     // Low band
-    const auto lowBandFrequency = jmin (static_cast<float> (0.5 * sampleRate), filterFrequency[0]->load());
+    const auto lowBandFrequency = juce::jmin (static_cast<float> (0.5 * sampleRate), filterFrequency[0]->load());
     const SpecialFilterType lowType = SpecialFilterType (static_cast<int> (*filterType[0]));
 
     switch (lowType)
@@ -127,7 +127,7 @@ void MultiEQAudioProcessor::updateGuiCoefficients()
             guiCoefficients[0] = IIR::Coefficients<double>::makeHighPass (sampleRate, lowBandFrequency, *filterQ[0]);
             break;
         case SpecialFilterType::LowShelf:
-            guiCoefficients[0] = IIR::Coefficients<double>::makeLowShelf (sampleRate, lowBandFrequency, *filterQ[0], Decibels::decibelsToGain (filterGain[0]->load()));
+            guiCoefficients[0] = IIR::Coefficients<double>::makeLowShelf (sampleRate, lowBandFrequency, *filterQ[0], juce::Decibels::decibelsToGain (filterGain[0]->load()));
             break;
         default:
             break;
@@ -135,7 +135,7 @@ void MultiEQAudioProcessor::updateGuiCoefficients()
 
 
     // High band
-    const auto highBandFrequency = jmin (static_cast<float> (0.5 * sampleRate), filterFrequency[numFilterBands - 1]->load());
+    const auto highBandFrequency = juce::jmin (static_cast<float> (0.5 * sampleRate), filterFrequency[numFilterBands - 1]->load());
     const SpecialFilterType highType = SpecialFilterType (4 + static_cast<int> (*filterType[numFilterBands - 1]));
 
     switch (highType)
@@ -155,7 +155,7 @@ void MultiEQAudioProcessor::updateGuiCoefficients()
             guiCoefficients[numFilterBands - 1] = IIR::Coefficients<double>::makeLowPass (sampleRate, highBandFrequency, *filterQ[numFilterBands - 1]);
             break;
         case SpecialFilterType::HighShelf:
-            guiCoefficients[numFilterBands - 1] = IIR::Coefficients<double>::makeHighShelf (sampleRate, highBandFrequency, *filterQ[numFilterBands - 1], Decibels::decibelsToGain (filterGain[numFilterBands - 1]->load()));
+            guiCoefficients[numFilterBands - 1] = IIR::Coefficients<double>::makeHighShelf (sampleRate, highBandFrequency, *filterQ[numFilterBands - 1], juce::Decibels::decibelsToGain (filterGain[numFilterBands - 1]->load()));
             break;
         default:
             break;
@@ -165,18 +165,18 @@ void MultiEQAudioProcessor::updateGuiCoefficients()
 
     for (int f = 1; f < numFilterBands - 1; ++f)
     {
-        const auto frequency = jmin (static_cast<float> (0.5 * sampleRate), filterFrequency[f]->load());
+        const auto frequency = juce::jmin (static_cast<float> (0.5 * sampleRate), filterFrequency[f]->load());
         const RegularFilterType type = RegularFilterType (2 + static_cast<int>(*filterType[f]));
         switch (type)
         {
             case RegularFilterType::LowShelf:
-                guiCoefficients[f] = IIR::Coefficients<double>::makeLowShelf (sampleRate, frequency, *filterQ[f], Decibels::decibelsToGain (filterGain[f]->load()));
+                guiCoefficients[f] = IIR::Coefficients<double>::makeLowShelf (sampleRate, frequency, *filterQ[f], juce::Decibels::decibelsToGain (filterGain[f]->load()));
                 break;
             case RegularFilterType::PeakFilter:
-                guiCoefficients[f] = IIR::Coefficients<double>::makePeakFilter (sampleRate, frequency, *filterQ[f], Decibels::decibelsToGain (filterGain[f]->load()));
+                guiCoefficients[f] = IIR::Coefficients<double>::makePeakFilter (sampleRate, frequency, *filterQ[f], juce::Decibels::decibelsToGain (filterGain[f]->load()));
                 break;
             case RegularFilterType::HighShelf:
-                guiCoefficients[f] = IIR::Coefficients<double>::makeHighShelf (sampleRate, frequency, *filterQ[f], Decibels::decibelsToGain (filterGain[f]->load()));
+                guiCoefficients[f] = IIR::Coefficients<double>::makeHighShelf (sampleRate, frequency, *filterQ[f], juce::Decibels::decibelsToGain (filterGain[f]->load()));
                 break;
             default:
                 break;
@@ -185,9 +185,9 @@ void MultiEQAudioProcessor::updateGuiCoefficients()
     }
 }
 
-inline dsp::IIR::Coefficients<float>::Ptr MultiEQAudioProcessor::createFilterCoefficients (const RegularFilterType type, const double sampleRate, const float frequency, const float Q, const float gain)
+inline juce::dsp::IIR::Coefficients<float>::Ptr MultiEQAudioProcessor::createFilterCoefficients (const RegularFilterType type, const double sampleRate, const float frequency, const float Q, const float gain)
 {
-    const auto f = jmin (static_cast<float> (0.5 * sampleRate), frequency);
+    const auto f = juce::jmin (static_cast<float> (0.5 * sampleRate), frequency);
     switch (type)
     {
         case RegularFilterType::FirstOrderHighPass:
@@ -217,9 +217,9 @@ inline dsp::IIR::Coefficients<float>::Ptr MultiEQAudioProcessor::createFilterCoe
     }
 }
 
-inline dsp::IIR::Coefficients<double>::Ptr MultiEQAudioProcessor::createFilterCoefficientsForGui (const RegularFilterType type, const double sampleRate, const float frequency, const float Q, const float gain)
+inline juce::dsp::IIR::Coefficients<double>::Ptr MultiEQAudioProcessor::createFilterCoefficientsForGui (const RegularFilterType type, const double sampleRate, const float frequency, const float Q, const float gain)
 {
-    const auto f = jmin (static_cast<float> (0.5 * sampleRate), frequency);
+    const auto f = juce::jmin (static_cast<float> (0.5 * sampleRate), frequency);
     switch (type)
     {
         case RegularFilterType::FirstOrderHighPass:
@@ -253,13 +253,13 @@ void MultiEQAudioProcessor::createLinkwitzRileyFilter (const bool isUpperBand)
 {
     if (isUpperBand)
     {
-        const auto frequency = jmin (static_cast<float> (0.5 * getSampleRate()), filterFrequency[numFilterBands - 1]->load());
+        const auto frequency = juce::jmin (static_cast<float> (0.5 * getSampleRate()), filterFrequency[numFilterBands - 1]->load());
         tempCoefficients[numFilterBands - 1] = IIR::Coefficients<float>::makeLowPass (getSampleRate(), frequency, *filterQ[numFilterBands - 1]);
         additionalTempCoefficients[1] = processorCoefficients[numFilterBands - 1];
     }
     else
     {
-        const auto frequency = jmin (static_cast<float> (0.5 * getSampleRate()), filterFrequency[0]->load());
+        const auto frequency = juce::jmin (static_cast<float> (0.5 * getSampleRate()), filterFrequency[0]->load());
         tempCoefficients[0] = IIR::Coefficients<float>::makeHighPass (getSampleRate(), frequency, *filterQ[0]);
         additionalTempCoefficients[0] = processorCoefficients[0];
     }
@@ -267,7 +267,7 @@ void MultiEQAudioProcessor::createLinkwitzRileyFilter (const bool isUpperBand)
 
 void MultiEQAudioProcessor::createFilterCoefficients (const int filterIndex, const double sampleRate)
 {
-    const int type = roundToInt (filterType[filterIndex]->load());
+    const int type = juce::roundToInt (filterType[filterIndex]->load());
     if (filterIndex == 0 && type == 2)
     {
         createLinkwitzRileyFilter (false);
@@ -319,7 +319,7 @@ void MultiEQAudioProcessor::createFilterCoefficients (const int filterIndex, con
                 }
                 break;
         }
-        tempCoefficients[filterIndex] = createFilterCoefficients (filterType, sampleRate, *filterFrequency[filterIndex], *filterQ[filterIndex], Decibels::decibelsToGain (filterGain[filterIndex]->load()));
+        tempCoefficients[filterIndex] = createFilterCoefficients (filterType, sampleRate, *filterFrequency[filterIndex], *filterQ[filterIndex], juce::Decibels::decibelsToGain (filterGain[filterIndex]->load()));
     }
 
 }
@@ -336,13 +336,13 @@ void MultiEQAudioProcessor::copyFilterCoefficientsToProcessor()
 }
 
 
-inline void MultiEQAudioProcessor::clear (AudioBlock<IIRfloat>& ab)
+inline void MultiEQAudioProcessor::clear (juce::dsp::AudioBlock<IIRfloat>& ab)
 {
     const int N = static_cast<int> (ab.getNumSamples()) * IIRfloat_elements;
     const int nCh = static_cast<int> (ab.getNumChannels());
 
     for (int ch = 0; ch < nCh; ++ch)
-        FloatVectorOperations::clear (reinterpret_cast<float*> (ab.getChannelPointer (ch)), N);
+        juce::FloatVectorOperations::clear (reinterpret_cast<float*> (ab.getChannelPointer (ch)), N);
 }
 
 //==============================================================================
@@ -361,12 +361,12 @@ void MultiEQAudioProcessor::setCurrentProgram (int index)
 {
 }
 
-const String MultiEQAudioProcessor::getProgramName (int index)
+const juce::String MultiEQAudioProcessor::getProgramName (int index)
 {
     return {};
 }
 
-void MultiEQAudioProcessor::changeProgramName (int index, const String& newName)
+void MultiEQAudioProcessor::changeProgramName (int index, const juce::String& newName)
 {
 }
 
@@ -392,12 +392,12 @@ void MultiEQAudioProcessor::prepareToPlay (double sampleRate, int samplesPerBloc
             filterArrays[f][i]->reset (IIRfloat (0.0f));
         }
 
-        interleavedData.add (new AudioBlock<IIRfloat> (interleavedBlockData[i], 1, samplesPerBlock));
+        interleavedData.add (new juce::dsp::AudioBlock<IIRfloat> (interleavedBlockData[i], 1, samplesPerBlock));
         //interleavedData.getLast()->clear(); // this one's broken in JUCE 5.4.5
         clear (*interleavedData.getLast());
     }
 
-    zero = AudioBlock<float> (zeroData, IIRfloat_elements, samplesPerBlock);
+    zero = juce::dsp::AudioBlock<float> (zeroData, IIRfloat_elements, samplesPerBlock);
     zero.clear();
 }
 
@@ -408,14 +408,14 @@ void MultiEQAudioProcessor::releaseResources()
 }
 
 
-void MultiEQAudioProcessor::processBlock (AudioSampleBuffer& buffer, MidiBuffer& midiMessages)
+void MultiEQAudioProcessor::processBlock (juce::AudioSampleBuffer& buffer, juce::MidiBuffer& midiMessages)
 {
     checkInputAndOutput (this, *inputChannelsSetting, *inputChannelsSetting, false);
-    ScopedNoDenormals noDenormals;
+    juce::ScopedNoDenormals noDenormals;
 
     const int L = buffer.getNumSamples();
 
-    const int maxNChIn = jmin (buffer.getNumChannels(), input.getSize());
+    const int maxNChIn = juce::jmin (buffer.getNumChannels(), input.getSize());
     if (maxNChIn < 1)
         return;
     
@@ -432,7 +432,7 @@ void MultiEQAudioProcessor::processBlock (AudioSampleBuffer& buffer, MidiBuffer&
     {
         for (int i = 0; i<nSIMDFilters; ++i)
         {
-            AudioDataConverters::interleaveSamples (buffer.getArrayOfReadPointers() + i* IIRfloat_elements,
+            juce::AudioDataConverters::interleaveSamples (buffer.getArrayOfReadPointers() + i* IIRfloat_elements,
                                                    reinterpret_cast<float*> (interleavedData[i]->getChannelPointer (0)), L,
                                                    static_cast<int> (IIRfloat_elements));
         }
@@ -442,7 +442,7 @@ void MultiEQAudioProcessor::processBlock (AudioSampleBuffer& buffer, MidiBuffer&
         int i;
         for (i = 0; i<nSIMDFilters-1; ++i)
         {
-            AudioDataConverters::interleaveSamples (buffer.getArrayOfReadPointers() + i* IIRfloat_elements,
+            juce::AudioDataConverters::interleaveSamples (buffer.getArrayOfReadPointers() + i* IIRfloat_elements,
                                                    reinterpret_cast<float*> (interleavedData[i]->getChannelPointer (0)), L,
                                                    static_cast<int> (IIRfloat_elements));
         }
@@ -457,7 +457,7 @@ void MultiEQAudioProcessor::processBlock (AudioSampleBuffer& buffer, MidiBuffer&
         {
             addr[ch] = zero.getChannelPointer(ch);
         }
-        AudioDataConverters::interleaveSamples (addr,
+        juce::AudioDataConverters::interleaveSamples (addr,
                                                reinterpret_cast<float*> (interleavedData[i]->getChannelPointer (0)), L,
                                                static_cast<int> (IIRfloat_elements));
     }
@@ -472,8 +472,8 @@ void MultiEQAudioProcessor::processBlock (AudioSampleBuffer& buffer, MidiBuffer&
             for (int i = 0; i < nSIMDFilters; ++i)
             {
                 const IIRfloat* chPtr[1] = {interleavedData[i]->getChannelPointer (0)};
-                AudioBlock<IIRfloat> ab (const_cast<IIRfloat**> (chPtr), 1, L);
-                ProcessContextReplacing<IIRfloat> context (ab);
+                juce::dsp::AudioBlock<IIRfloat> ab (const_cast<IIRfloat**> (chPtr), 1, L);
+                juce::dsp::ProcessContextReplacing<IIRfloat> context (ab);
                 filterArrays[f][i]->process (context);
             }
         }
@@ -485,8 +485,8 @@ void MultiEQAudioProcessor::processBlock (AudioSampleBuffer& buffer, MidiBuffer&
         for (int i = 0; i < nSIMDFilters; ++i)
         {
             const IIRfloat* chPtr[1] = {chPtr[0] = interleavedData[i]->getChannelPointer (0)};
-            AudioBlock<IIRfloat> ab (const_cast<IIRfloat**> (chPtr), 1, L);
-            ProcessContextReplacing<IIRfloat> context (ab);
+            juce::dsp::AudioBlock<IIRfloat> ab (const_cast<IIRfloat**> (chPtr), 1, L);
+            juce::dsp::ProcessContextReplacing<IIRfloat> context (ab);
             additionalFilterArrays[0][i]->process (context);
         }
     }
@@ -495,8 +495,8 @@ void MultiEQAudioProcessor::processBlock (AudioSampleBuffer& buffer, MidiBuffer&
         for (int i = 0; i < nSIMDFilters; ++i)
         {
             const IIRfloat* chPtr[1] = {interleavedData[i]->getChannelPointer (0)};
-            AudioBlock<IIRfloat> ab (const_cast<IIRfloat**> (chPtr), 1, L);
-            ProcessContextReplacing<IIRfloat> context (ab);
+            juce::dsp::AudioBlock<IIRfloat> ab (const_cast<IIRfloat**> (chPtr), 1, L);
+            juce::dsp::ProcessContextReplacing<IIRfloat> context (ab);
             additionalFilterArrays[1][i]->process (context);
         }
     }
@@ -507,7 +507,7 @@ void MultiEQAudioProcessor::processBlock (AudioSampleBuffer& buffer, MidiBuffer&
     {
         for (int i = 0; i<nSIMDFilters; ++i)
         {
-            AudioDataConverters::deinterleaveSamples (reinterpret_cast<float*> (interleavedData[i]->getChannelPointer (0)),
+            juce::AudioDataConverters::deinterleaveSamples (reinterpret_cast<float*> (interleavedData[i]->getChannelPointer (0)),
                                                       buffer.getArrayOfWritePointers() + i * IIRfloat_elements,
                                                       L,
                                                       static_cast<int> (IIRfloat_elements));
@@ -518,7 +518,7 @@ void MultiEQAudioProcessor::processBlock (AudioSampleBuffer& buffer, MidiBuffer&
         int i;
         for (i = 0; i<nSIMDFilters-1; ++i)
         {
-            AudioDataConverters::deinterleaveSamples (reinterpret_cast<float*> (interleavedData[i]->getChannelPointer (0)),
+            juce::AudioDataConverters::deinterleaveSamples (reinterpret_cast<float*> (interleavedData[i]->getChannelPointer (0)),
                                                       buffer.getArrayOfWritePointers() + i * IIRfloat_elements,
                                                       L,
                                                       static_cast<int> (IIRfloat_elements));
@@ -534,7 +534,7 @@ void MultiEQAudioProcessor::processBlock (AudioSampleBuffer& buffer, MidiBuffer&
         {
             addr[ch] = zero.getChannelPointer (ch);
         }
-        AudioDataConverters::deinterleaveSamples (reinterpret_cast<float*> (interleavedData[i]->getChannelPointer (0)),
+        juce::AudioDataConverters::deinterleaveSamples (reinterpret_cast<float*> (interleavedData[i]->getChannelPointer (0)),
                                                  addr,
                                                  L,
                                                  static_cast<int> (IIRfloat_elements));
@@ -549,34 +549,34 @@ bool MultiEQAudioProcessor::hasEditor() const
     return true; // (change this to false if you choose to not supply an editor)
 }
 
-AudioProcessorEditor* MultiEQAudioProcessor::createEditor()
+juce::AudioProcessorEditor* MultiEQAudioProcessor::createEditor()
 {
     return new MultiEQAudioProcessorEditor (*this, parameters);
 }
 
 //==============================================================================
-void MultiEQAudioProcessor::getStateInformation (MemoryBlock& destData)
+void MultiEQAudioProcessor::getStateInformation (juce::MemoryBlock& destData)
 {
   auto state = parameters.copyState();
 
   auto oscConfig = state.getOrCreateChildWithName ("OSCConfig", nullptr);
   oscConfig.copyPropertiesFrom (oscParameterInterface.getConfig(), nullptr);
 
-  std::unique_ptr<XmlElement> xml (state.createXml());
+  std::unique_ptr<juce::XmlElement> xml (state.createXml());
   copyXmlToBinary (*xml, destData);
 }
 
 
 void MultiEQAudioProcessor::setStateInformation (const void* data, int sizeInBytes)
 {
-    std::unique_ptr<XmlElement> xmlState (getXmlFromBinary (data, sizeInBytes));
+    std::unique_ptr<juce::XmlElement> xmlState (getXmlFromBinary (data, sizeInBytes));
     if (xmlState.get() != nullptr)
         if (xmlState->hasTagName (parameters.state.getType()))
         {
-            parameters.replaceState (ValueTree::fromXml (*xmlState));
+            parameters.replaceState (juce::ValueTree::fromXml (*xmlState));
             if (parameters.state.hasProperty ("OSCPort")) // legacy
             {
-                oscParameterInterface.getOSCReceiver().connect (parameters.state.getProperty ("OSCPort", var (-1)));
+                oscParameterInterface.getOSCReceiver().connect (parameters.state.getProperty ("OSCPort", juce::var (-1)));
                 parameters.state.removeProperty ("OSCPort", nullptr);
             }
 
@@ -587,7 +587,7 @@ void MultiEQAudioProcessor::setStateInformation (const void* data, int sizeInByt
 }
 
 //==============================================================================
-void MultiEQAudioProcessor::parameterChanged (const String &parameterID, float newValue)
+void MultiEQAudioProcessor::parameterChanged (const juce::String &parameterID, float newValue)
 {
     DBG ("Parameter with ID " << parameterID << " has changed. New value: " << newValue);
 
@@ -611,25 +611,25 @@ void MultiEQAudioProcessor::updateBuffers()
 }
 
 //==============================================================================
-std::vector<std::unique_ptr<RangedAudioParameter>> MultiEQAudioProcessor::createParameterLayout()
+std::vector<std::unique_ptr<juce::RangedAudioParameter>> MultiEQAudioProcessor::createParameterLayout()
 {
     // add your audio parameters here
-    std::vector<std::unique_ptr<RangedAudioParameter>> params;
+    std::vector<std::unique_ptr<juce::RangedAudioParameter>> params;
 
 
 
     params.push_back (OSCParameterInterface::createParameterTheOldWay ("inputChannelsSetting", "Number of input channels ", "",
-                                     NormalisableRange<float> (0.0f, 64.0f, 1.0f), 0.0f,
-                                     [](float value) {return value < 0.5f ? "Auto" : String (value);}, nullptr));
+                                     juce::NormalisableRange<float> (0.0f, 64.0f, 1.0f), 0.0f,
+                                     [](float value) {return value < 0.5f ? "Auto" : juce::String (value);}, nullptr));
 
 
     int i = 0;
-    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterEnabled" + String (i), "Filter Enablement " + String (i + 1), "",
-                                     NormalisableRange<float> (0.0f, 1.0f, 1.0f), 1.0f,
-                                     [](float value) { return value < 0.5 ? String ("OFF") : String ("ON");}, nullptr));
+    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterEnabled" + juce::String (i), "Filter Enablement " + juce::String (i + 1), "",
+                                     juce::NormalisableRange<float> (0.0f, 1.0f, 1.0f), 1.0f,
+                                     [](float value) { return value < 0.5 ? juce::String ("OFF") : juce::String ("ON");}, nullptr));
 
-    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterType" + String (i), "Filter Type " + String (i + 1), "",
-                                     NormalisableRange<float> (0.0f, 3.0f, 1.0f),  filterTypePresets[i],
+    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterType" + juce::String (i), "Filter Type " + juce::String (i + 1), "",
+                                     juce::NormalisableRange<float> (0.0f, 3.0f, 1.0f),  filterTypePresets[i],
                                      [](float value) {
                                          if (value < 0.5f) return "HP (6dB/oct)";
                                          else if (value >= 0.5f && value < 1.5f) return "HP (12dB/oct)";
@@ -637,58 +637,58 @@ std::vector<std::unique_ptr<RangedAudioParameter>> MultiEQAudioProcessor::create
                                          else return "Low-shelf";},
                                      nullptr));
 
-    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterFrequency" + String (i), "Filter Frequency " + String (i + 1), "Hz",
-                                     NormalisableRange<float> (20.0f, 20000.0f, 1.0f, 0.4f), filterFrequencyPresets[i],
-                                     [](float value) { return String(value, 0); }, nullptr));
+    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterFrequency" + juce::String (i), "Filter Frequency " + juce::String (i + 1), "Hz",
+                                     juce::NormalisableRange<float> (20.0f, 20000.0f, 1.0f, 0.4f), filterFrequencyPresets[i],
+                                     [](float value) { return juce::String(value, 0); }, nullptr));
 
-    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterQ" + String (i), "Filter Q " + String (i+1), "",
-                                     NormalisableRange<float> (0.05f, 8.0f, 0.05f), 0.7f,
-                                     [](float value) { return String (value, 2); },
+    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterQ" + juce::String (i), "Filter Q " + juce::String (i+1), "",
+                                     juce::NormalisableRange<float> (0.05f, 8.0f, 0.05f), 0.7f,
+                                     [](float value) { return juce::String (value, 2); },
                                      nullptr));
 
-    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterGain" + String (i), "Filter Gain " + String (i + 1), "dB",
-                                     NormalisableRange<float> (-60.0f, 15.0f, 0.1f), 0.0f,
-                                     [](float value) { return String (value, 1); },
+    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterGain" + juce::String (i), "Filter Gain " + juce::String (i + 1), "dB",
+                                     juce::NormalisableRange<float> (-60.0f, 15.0f, 0.1f), 0.0f,
+                                     [](float value) { return juce::String (value, 1); },
                                      nullptr));
 
 
     for (int i = 1; i < numFilterBands - 1; ++i)
     {
-        params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterEnabled" + String (i), "Filter Enablement " + String (i + 1), "",
-                                         NormalisableRange<float> (0.0f, 1.0f, 1.0f), 1.0f,
-                                         [](float value) { return value < 0.5 ? String ("OFF") : String ("ON");}, nullptr));
+        params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterEnabled" + juce::String (i), "Filter Enablement " + juce::String (i + 1), "",
+                                         juce::NormalisableRange<float> (0.0f, 1.0f, 1.0f), 1.0f,
+                                         [](float value) { return value < 0.5 ? juce::String ("OFF") : juce::String ("ON");}, nullptr));
 
-        params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterType" + String (i), "Filter Type " + String (i + 1), "",
-                                         NormalisableRange<float> (0.0f, 2.0f, 1.0f),  filterTypePresets[i],
+        params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterType" + juce::String (i), "Filter Type " + juce::String (i + 1), "",
+                                         juce::NormalisableRange<float> (0.0f, 2.0f, 1.0f),  filterTypePresets[i],
                                          [](float value) {
                                              if (value < 0.5f) return "Low-shelf";
                                              else if (value >= 0.5f && value < 1.5f) return "Peak";
                                              else return "High-shelf";},
                                          nullptr));
 
-        params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterFrequency" + String (i), "Filter Frequency " + String (i + 1), "Hz",
-                                         NormalisableRange<float> (20.0f, 20000.0f, 1.0f, 0.4f), filterFrequencyPresets[i],
-                                         [](float value) { return String(value, 0); }, nullptr));
+        params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterFrequency" + juce::String (i), "Filter Frequency " + juce::String (i + 1), "Hz",
+                                         juce::NormalisableRange<float> (20.0f, 20000.0f, 1.0f, 0.4f), filterFrequencyPresets[i],
+                                         [](float value) { return juce::String(value, 0); }, nullptr));
 
-        params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterQ" + String (i), "Filter Q " + String (i+1), "",
-                                         NormalisableRange<float> (0.05f, 8.0f, 0.05f), 0.7f,
-                                         [](float value) { return String (value, 2); },
+        params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterQ" + juce::String (i), "Filter Q " + juce::String (i+1), "",
+                                         juce::NormalisableRange<float> (0.05f, 8.0f, 0.05f), 0.7f,
+                                         [](float value) { return juce::String (value, 2); },
                                          nullptr));
 
-        params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterGain" + String (i), "Filter Gain " + String (i + 1), "dB",
-                                         NormalisableRange<float> (-60.0f, 15.0f, 0.1f), 0.0f,
-                                         [](float value) { return String (value, 1); },
+        params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterGain" + juce::String (i), "Filter Gain " + juce::String (i + 1), "dB",
+                                         juce::NormalisableRange<float> (-60.0f, 15.0f, 0.1f), 0.0f,
+                                         [](float value) { return juce::String (value, 1); },
                                          nullptr));
     }
 
     i = numFilterBands - 1;
 
-    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterEnabled" + String (i), "Filter Enablement " + String (i + 1), "",
-                                     NormalisableRange<float> (0.0f, 1.0f, 1.0f), 1.0f,
-                                     [](float value) { return value < 0.5 ? String ("OFF") : String ("ON");}, nullptr));
+    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterEnabled" + juce::String (i), "Filter Enablement " + juce::String (i + 1), "",
+                                     juce::NormalisableRange<float> (0.0f, 1.0f, 1.0f), 1.0f,
+                                     [](float value) { return value < 0.5 ? juce::String ("OFF") : juce::String ("ON");}, nullptr));
 
-    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterType" + String (i), "Filter Type " + String (i + 1), "",
-                                     NormalisableRange<float> (0.0f, 3.0f, 1.0f),  filterTypePresets[i],
+    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterType" + juce::String (i), "Filter Type " + juce::String (i + 1), "",
+                                     juce::NormalisableRange<float> (0.0f, 3.0f, 1.0f),  filterTypePresets[i],
                                      [](float value) {
                                          if (value < 0.5f) return "LP (6dB/Oct)";
                                          else if (value >= 0.5f && value < 1.5f) return "LP (12dB/oct)";
@@ -696,18 +696,18 @@ std::vector<std::unique_ptr<RangedAudioParameter>> MultiEQAudioProcessor::create
                                          else return "High-shelf";},
                                      nullptr));
 
-    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterFrequency" + String (i), "Filter Frequency " + String (i + 1), "Hz",
-                                     NormalisableRange<float> (20.0f, 20000.0f, 1.0f, 0.4f), filterFrequencyPresets[i],
-                                     [](float value) { return String(value, 0); }, nullptr));
+    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterFrequency" + juce::String (i), "Filter Frequency " + juce::String (i + 1), "Hz",
+                                     juce::NormalisableRange<float> (20.0f, 20000.0f, 1.0f, 0.4f), filterFrequencyPresets[i],
+                                     [](float value) { return juce::String(value, 0); }, nullptr));
 
-    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterQ" + String (i), "Filter Q " + String (i+1), "",
-                                     NormalisableRange<float> (0.05f, 8.0f, 0.05f), 0.7f,
-                                     [](float value) { return String (value, 2); },
+    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterQ" + juce::String (i), "Filter Q " + juce::String (i+1), "",
+                                     juce::NormalisableRange<float> (0.05f, 8.0f, 0.05f), 0.7f,
+                                     [](float value) { return juce::String (value, 2); },
                                      nullptr));
 
-    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterGain" + String (i), "Filter Gain " + String (i + 1), "dB",
-                                     NormalisableRange<float> (-60.0f, 15.0f, 0.1f), 0.0f,
-                                     [](float value) { return String (value, 1); },
+    params.push_back (OSCParameterInterface::createParameterTheOldWay ("filterGain" + juce::String (i), "Filter Gain " + juce::String (i + 1), "dB",
+                                     juce::NormalisableRange<float> (-60.0f, 15.0f, 0.1f), 0.0f,
+                                     [](float value) { return juce::String (value, 1); },
                                      nullptr));
 
 
@@ -716,7 +716,7 @@ std::vector<std::unique_ptr<RangedAudioParameter>> MultiEQAudioProcessor::create
 
 //==============================================================================
 // This creates new instances of the plugin..
-AudioProcessor* JUCE_CALLTYPE createPluginFilter()
+juce::AudioProcessor* JUCE_CALLTYPE createPluginFilter()
 {
     return new MultiEQAudioProcessor();
 }
