@@ -42,46 +42,46 @@ public:
     constexpr static int numberOfOutputChannels = 64;
     //==============================================================================
     OmniCompressorAudioProcessor();
-    ~OmniCompressorAudioProcessor();
+    ~OmniCompressorAudioProcessor() override;
 
     //==============================================================================
     void prepareToPlay (double sampleRate, int samplesPerBlock) override;
     void releaseResources() override;
 
 
-    void processBlock (AudioSampleBuffer&, MidiBuffer&) override;
+    void processBlock (juce::AudioSampleBuffer&, juce::MidiBuffer&) override;
 
     //==============================================================================
-    AudioProcessorEditor* createEditor() override;
+    juce::AudioProcessorEditor* createEditor() override;
     bool hasEditor() const override;
 
     //==============================================================================
     int getNumPrograms() override;
     int getCurrentProgram() override;
     void setCurrentProgram (int index) override;
-    const String getProgramName (int index) override;
-    void changeProgramName (int index, const String& newName) override;
+    const juce::String getProgramName (int index) override;
+    void changeProgramName (int index, const juce::String& newName) override;
 
     //==============================================================================
-    void getStateInformation (MemoryBlock& destData) override;
+    void getStateInformation (juce::MemoryBlock& destData) override;
     void setStateInformation (const void* data, int sizeInBytes) override;
-    void parameterChanged (const String &parameterID, float newValue) override;
+    void parameterChanged (const juce::String &parameterID, float newValue) override;
 
     //======= Parameters ===========================================================
-    std::vector<std::unique_ptr<RangedAudioParameter>> createParameterLayout();
+    std::vector<std::unique_ptr<juce::RangedAudioParameter>> createParameterLayout();
 
     //==============================================================================
-    Atomic<float> maxRMS;
-    Atomic<float> maxGR;
-    Compressor compressor;
+    juce::Atomic<float> maxRMS;
+    juce::Atomic<float> maxGR;
+    iem::Compressor compressor;
 
 private:
     //==============================================================================
     Delay delay;
     LookAheadGainReduction grProcessing;
 
-    Array<float> RMS, allGR;
-    AudioBuffer<float> gains;
+    juce::Array<float> RMS, allGR;
+    juce::AudioBuffer<float> gains;
 
     float GR;
     std::atomic<float>* orderSetting;
