@@ -26,28 +26,28 @@
 //==============================================================================
 /*
 */
-class SimpleLabel    : public Component
+class SimpleLabel    : public juce::Component
 {
 public:
     SimpleLabel() {}
 
-    SimpleLabel (String textToDisplay)
+    SimpleLabel (juce::String textToDisplay)
     {
         text = textToDisplay;
     }
 
-    void setText(String newText)
+    void setText (juce::String newText)
     {
         text = newText;
         repaint();
     }
-    void setText(String newText, bool newBold)
+    void setText (juce::String newText, bool newBold)
     {
         text = newText;
         isBold = newBold;
         repaint();
     }
-    void setText(String newText, bool newBold, Justification newJustification)
+    void setText (juce::String newText, bool newBold, juce::Justification newJustification)
     {
         text = newText;
         isBold = newBold;
@@ -55,13 +55,13 @@ public:
         repaint();
     }
 
-    void setJustification(Justification newJustification)
+    void setJustification (juce::Justification newJustification)
     {
         justification = newJustification;
         repaint();
     }
 
-    void setTextColour(const Colour newColour)
+    void setTextColour (const juce::Colour newColour)
     {
         if (colour != newColour)
         {
@@ -75,17 +75,17 @@ public:
         repaint();
     }
 
-    void paint (Graphics& g) override
+    void paint (juce::Graphics& g) override
     {
-        Rectangle<int> bounds = getLocalBounds();
+        juce::Rectangle<int> bounds = getLocalBounds();
         paintSimpleLabel(g, bounds, text, isBold, justification);
     }
 
-    virtual void paintSimpleLabel (Graphics& g, Rectangle<int> bounds, String labelText, bool isBoldFlag, Justification labelJustification)
+    virtual void paintSimpleLabel (juce::Graphics& g, juce::Rectangle<int> bounds, juce::String labelText, bool isBoldFlag, juce::Justification labelJustification)
     {
         g.setColour (colour.withMultipliedAlpha(this->isEnabled() ? 1.0f : 0.4f));
         g.setFont (bounds.getHeight());
-        g.setFont (getLookAndFeel().getTypefaceForFont (Font (bounds.getHeight(), isBoldFlag ? 1 : 0)));
+        g.setFont (getLookAndFeel().getTypefaceForFont (juce::Font (bounds.getHeight(), isBoldFlag ? 1 : 0)));
         g.drawText (labelText, bounds, labelJustification, true);
     }
 
@@ -95,17 +95,17 @@ public:
 
 private:
     JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (SimpleLabel)
-    String text = "";
+    juce::String text = "";
     bool isBold = false;
-    Colour colour = Colours::white;
-    Justification justification = Justification::centred;
+    juce::Colour colour = juce::Colours::white;
+    juce::Justification justification = juce::Justification::centred;
 };
 
 
 //==============================================================================
 /*
  */
-class TripleLabel    : public Component
+class TripleLabel    : public juce::Component
 {
 public:
     TripleLabel()
@@ -115,7 +115,8 @@ public:
 
     }
 
-    void setText(String newLeftText, String newMiddleText, String newRightText, bool newLeftBold, bool newMiddleBold, bool newRightBold) {
+    void setText (juce::String newLeftText, juce::String newMiddleText, juce::String newRightText, bool newLeftBold, bool newMiddleBold, bool newRightBold)
+    {
         leftText = newLeftText;
         middleText = newMiddleText;
         rightText = newRightText;
@@ -126,33 +127,33 @@ public:
         repaint();
     }
 
-    void paint (Graphics& g) override
+    void paint (juce::Graphics& g) override
     {
-        Rectangle<int> bounds = getLocalBounds();
+        juce::Rectangle<int> bounds = getLocalBounds();
         paintTripleLabel(g, bounds, leftText, middleText, rightText, leftBold, middleBold, rightBold);
     }
 
-    virtual void paintTripleLabel (Graphics& g, Rectangle<int> bounds, String leftLabelText, String middleLabelText, String rightLabelText, bool leftBoldFlag, bool middleBoldFlag, bool rightBoldFlag)
+    virtual void paintTripleLabel (juce::Graphics& g, juce::Rectangle<int> bounds, juce::String leftLabelText, juce::String middleLabelText, juce::String rightLabelText, bool leftBoldFlag, bool middleBoldFlag, bool rightBoldFlag)
     {
-        g.setColour (Colours::white);
-        Font tempFont;
-        tempFont.setHeight(bounds.getHeight());
+        g.setColour (juce::Colours::white);
+        juce::Font tempFont;
+        tempFont.setHeight (bounds.getHeight());
         int height = bounds.getHeight();
 
         tempFont.setStyleFlags (leftBoldFlag ? 1 : 0);
-        g.setFont(getLookAndFeel().getTypefaceForFont(tempFont));
-        g.setFont(height);
-        g.drawText (leftLabelText, bounds, Justification::left, true);
+        g.setFont (getLookAndFeel().getTypefaceForFont(tempFont));
+        g.setFont (height);
+        g.drawText (leftLabelText, bounds, juce::Justification::left, true);
 
         tempFont.setStyleFlags (middleBoldFlag ? 1 : 0);
-        g.setFont(getLookAndFeel().getTypefaceForFont(tempFont));
-        g.setFont(height + (middleBold ? 2 : 0));
-        g.drawText (middleLabelText, bounds, Justification::centred, true);
+        g.setFont (getLookAndFeel().getTypefaceForFont(tempFont));
+        g.setFont (height + (middleBold ? 2 : 0));
+        g.drawText (middleLabelText, bounds, juce::Justification::centred, true);
 
         tempFont.setStyleFlags (rightBoldFlag ? 1 : 0);
-        g.setFont(getLookAndFeel().getTypefaceForFont(tempFont));
-        g.setFont(height);
-        g.drawText (rightLabelText, bounds, Justification::right, true);
+        g.setFont (getLookAndFeel().getTypefaceForFont(tempFont));
+        g.setFont (height);
+        g.drawText (rightLabelText, bounds, juce::Justification::right, true);
     }
 
 
@@ -161,10 +162,10 @@ public:
     }
 
 private:
+    
     JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (TripleLabel)
-    String leftText = "";
-    String middleText = "";
-    String rightText = "";
+    juce::String leftText = "";
+    juce::String middleText = "";
+    juce::String rightText = "";
     bool leftBold, middleBold, rightBold;
-
 };
