@@ -26,46 +26,45 @@
 #include "../../resources/Quaternion.h"
 
 
-class SpherePannerBackground :  public Component
+class SpherePannerBackground :  public juce::Component
 {
 
 public:
-    SpherePannerBackground() : Component()
+    SpherePannerBackground()
     {
-        setBufferedToImage(true);
+        setBufferedToImage (true);
     };
 
     ~SpherePannerBackground() {};
 
     void resized() override
     {
-        const Rectangle<float> sphere (getLocalBounds().reduced (10, 10).toFloat());
+        auto sphere = getLocalBounds().reduced (10, 10).toFloat();
 
-        radius = 0.5f * jmin (sphere.getWidth(), sphere.getHeight());
-        centre = getLocalBounds().getCentre();
+        radius = 0.5f * juce::jmin (sphere.getWidth(), sphere.getHeight());
         sphereArea.setBounds (0, 0, 2 * radius, 2 * radius);
-        sphereArea.setCentre (centre.toFloat());
+        sphereArea.setCentre (getLocalBounds().getCentre().toFloat());
     };
 
-    void paint (Graphics& g) override
+    void paint (juce::Graphics& g) override
     {
-        const Rectangle<float> bounds = getLocalBounds().toFloat();
+        const auto bounds = getLocalBounds().toFloat();
         const float centreX = bounds.getCentreX();
         const float centreY = bounds.getCentreY();
 
-        g.setColour (Colours::white);
+        g.setColour (juce::Colours::white);
         g.drawEllipse (centreX-radius, centreY - radius, 2.0f * radius, 2.0f * radius, 1.0f);
 
-        g.setFont (getLookAndFeel().getTypefaceForFont (Font (12.0f, 1)));
+        g.setFont (getLookAndFeel().getTypefaceForFont (juce::Font (12.0f, 1)));
         g.setFont (12.0f);
-        g.drawText ("FRONT", centreX-15, centreY-radius - 12, 30, 12, Justification::centred);
-        g.drawText ("BACK", centreX-15, centreY+radius, 30, 12, Justification::centred);
-        g.drawFittedText ("L\nE\nF\nT", sphereArea.getX() - 10, centreY - 40, 10, 80, Justification::centred, 4);
-        g.drawFittedText ("R\nI\nG\nH\nT", sphereArea.getRight(), centreY - 40, 10, 80, Justification::centred, 5);
+        g.drawText ("FRONT", centreX-15, centreY-radius - 12, 30, 12, juce::Justification::centred);
+        g.drawText ("BACK", centreX-15, centreY+radius, 30, 12, juce::Justification::centred);
+        g.drawFittedText ("L\nE\nF\nT", sphereArea.getX() - 10, centreY - 40, 10, 80, juce::Justification::centred, 4);
+        g.drawFittedText ("R\nI\nG\nH\nT", sphereArea.getRight(), centreY - 40, 10, 80, juce::Justification::centred, 5);
 
-        g.setColour (Colours::steelblue.withMultipliedAlpha (0.2f));
-        Path circles;
+        g.setColour (juce::Colours::steelblue.withMultipliedAlpha (0.2f));
 
+        juce::Path circles;
         for (int deg = 75; deg >= 0; deg -= 15)
         {
             float rCirc;
@@ -73,58 +72,58 @@ public:
                 rCirc = radius * std::cos (Conversions<float>::degreesToRadians (deg));
             else
                 rCirc = radius * (90 - deg) / 90;
-            circles.addEllipse(centreX - rCirc, centreY - rCirc, 2.0f * rCirc, 2.0f * rCirc);
-            g.fillPath(circles);
+            circles.addEllipse (centreX - rCirc, centreY - rCirc, 2.0f * rCirc, 2.0f * rCirc);
+            g.fillPath (circles);
         }
 
-        g.setColour (Colours::steelblue.withMultipliedAlpha (0.7f));
-        g.strokePath (circles, PathStrokeType (.5f));
+        g.setColour (juce::Colours::steelblue.withMultipliedAlpha (0.7f));
+        g.strokePath (circles, juce::PathStrokeType (.5f));
 
-        ColourGradient gradient(Colours::black.withMultipliedAlpha (0.7f), centreX, centreY, Colours::black.withMultipliedAlpha (0.1f), 0, 0, true);
+        juce::ColourGradient gradient (juce::Colours::black.withMultipliedAlpha (0.7f), centreX, centreY, juce::Colours::black.withMultipliedAlpha (0.1f), 0, 0, true);
         g.setGradientFill (gradient);
 
-        Path line;
+        juce::Path line;
         line.startNewSubPath (centreX, centreY - radius);
         line.lineTo (centreX, centreY + radius);
 
-        Path path;
+        juce::Path path;
         path.addPath (line);
-        path.addPath (line, AffineTransform().rotation (0.25f * MathConstants<float>::pi, centreX, centreY));
-        path.addPath (line, AffineTransform().rotation (0.5f * MathConstants<float>::pi, centreX, centreY));
-        path.addPath (line, AffineTransform().rotation (0.75f * MathConstants<float>::pi, centreX, centreY));
+        path.addPath (line, juce::AffineTransform().rotation (0.25f * juce::MathConstants<float>::pi, centreX, centreY));
+        path.addPath (line, juce::AffineTransform().rotation (0.5f * juce::MathConstants<float>::pi, centreX, centreY));
+        path.addPath (line, juce::AffineTransform().rotation (0.75f * juce::MathConstants<float>::pi, centreX, centreY));
 
-        g.strokePath(path, PathStrokeType (0.5f));
+        g.strokePath(path, juce::PathStrokeType (0.5f));
     }
+
     void setElevationStyle (bool linear) { linearElevation = linear; };
 
 private:
     float radius = 1.0f;
-    Rectangle<float> sphereArea;
-    Point<int> centre;
+    juce::Rectangle<float> sphereArea;
     bool linearElevation = false;
 };
 
 
 
-class SpherePanner :  public Component
+class SpherePanner :  public juce::Component
 {
 public:
-    SpherePanner() : Component()
+    SpherePanner()
     {
         setBufferedToImage (true);
 
         addAndMakeVisible (background);
         background.addMouseListener (this, false); // could this be risky?
-    };
+    }
 
-    ~SpherePanner() {};
+    ~SpherePanner() override = default;
 
 
     class Listener
     {
     public:
         virtual ~Listener() {}
-        virtual void mouseWheelOnSpherePannerMoved (SpherePanner* sphere, const MouseEvent &event, const MouseWheelDetails &wheel) {};
+        virtual void mouseWheelOnSpherePannerMoved (SpherePanner* sphere, const juce::MouseEvent &event, const juce::MouseWheelDetails &wheel) {};
     };
 
     class Element
@@ -133,32 +132,32 @@ public:
         Element() {}
         virtual ~Element() {}
 
-        virtual void startMovement() { };
-        virtual void moveElement (const MouseEvent &event, Point<int> centre, float radius, bool upBeforeDrag,  bool linearElevation, bool rightClick = false) = 0;
-        virtual void stopMovement() { };
+        virtual void startMovement() { }
+        virtual void moveElement (const juce::MouseEvent &event, juce::Point<int> centre, float radius, bool upBeforeDrag,  bool linearElevation, bool rightClick = false) = 0;
+        virtual void stopMovement() { }
 
         /**
          Get cartesian coordinates
          */
-        virtual Vector3D<float> getCoordinates() = 0;
+        virtual juce::Vector3D<float> getCoordinates() = 0;
 
 
         void setActive (bool isActive) { active = isActive; }
         bool isActive() { return active; }
 
-        void setColour (Colour newColour) { colour = newColour; }
-        void setTextColour (Colour newColour) { textColour = newColour; }
-        Colour getColour() { return colour; }
-        Colour getTextColour() { return textColour; }
+        void setColour (juce::Colour newColour) { colour = newColour; }
+        void setTextColour (juce::Colour newColour) { textColour = newColour; }
+        juce::Colour getColour() { return colour; }
+        juce::Colour getTextColour() { return textColour; }
 
-        void setLabel (String newLabel) {label = newLabel;}
+        void setLabel (juce::String newLabel) {label = newLabel;}
 
         void setGrabPriority (int newPriority) { grabPriority = newPriority; }
         int getGrabPriority() {return grabPriority;}
         void setGrabRadius (float newRadius) { grabRadius = newRadius; }
         float getGrabRadius() { return grabRadius; }
 
-        String getLabel() {return label;};
+        juce::String getLabel() { return label; }
 
     private:
         bool active = true;
@@ -166,19 +165,19 @@ public:
         float grabRadius = 0.123f;
         int grabPriority = 0;
 
-        Colour colour = Colours::white;
-        Colour textColour = Colours::black;
-        String label = "";
+        juce::Colour colour = juce::Colours::white;
+        juce::Colour textColour = juce::Colours::black;
+        juce::String label = "";
     };
 
     class StandardElement : public Element
     {
     public:
-        StandardElement() : Element() {}
+        StandardElement() = default;
 
-        void moveElement (const MouseEvent &event, Point<int> centre, float radius, bool upBeforeDrag, bool linearElevation, bool rightClick) override
+        void moveElement (const juce::MouseEvent &event, juce::Point<int> centre, float radius, bool upBeforeDrag, bool linearElevation, bool rightClick) override
         {
-            Point<int> pos = event.getPosition();
+            auto pos = event.getPosition();
             const float azimuth = -1.0f * centre.getAngleToPoint (pos);
             float r = centre.getDistanceFrom (pos) / radius;
             if (r > 1.0f)
@@ -188,7 +187,7 @@ public:
             }
 
             if (linearElevation)
-                r = std::sin (r * MathConstants<float>::halfPi);
+                r = std::sin (r * juce::MathConstants<float>::halfPi);
 
 
             float elevation = std::acos (r);
@@ -201,12 +200,12 @@ public:
         /*
          Get cartesian coordinates
          */
-        Vector3D<float> getCoordinates() override
+        juce::Vector3D<float> getCoordinates() override
         {
             return position;
         };
 
-        bool setCoordinates (Vector3D<float> newPosition) // is true when position is updated (use it for repainting)
+        bool setCoordinates (juce::Vector3D<float> newPosition) // is true when position is updated (use it for repainting)
         {
             if (position.x != newPosition.x || position.y != newPosition.y || position.z != newPosition.z)
             {
@@ -217,13 +216,13 @@ public:
         }
 
     private:
-        Vector3D<float> position;
+        juce::Vector3D<float> position;
     };
 
     class AzimuthElevationParameterElement : public Element
     {
     public:
-        AzimuthElevationParameterElement (AudioProcessorParameter& azimuthParameter, NormalisableRange<float> azimuthParameterRange, AudioProcessorParameter& elevationParameter, NormalisableRange<float> elevationParameterRange) : Element(), azimuth (azimuthParameter), azimuthRange (azimuthParameterRange), elevation (elevationParameter), elevationRange (elevationParameterRange) {}
+        AzimuthElevationParameterElement (juce::AudioProcessorParameter& azimuthParameter, juce::NormalisableRange<float> azimuthParameterRange, juce::AudioProcessorParameter& elevationParameter, juce::NormalisableRange<float> elevationParameterRange) : Element(), azimuth (azimuthParameter), azimuthRange (azimuthParameterRange), elevation (elevationParameter), elevationRange (elevationParameterRange) {}
 
         void startMovement() override
         {
@@ -231,9 +230,9 @@ public:
             elevation.beginChangeGesture();
         };
 
-        void moveElement (const MouseEvent &event, Point<int> centre, float radius, bool upBeforeDrag,  bool linearElevation, bool rightClick) override
+        void moveElement (const juce::MouseEvent &event, juce::Point<int> centre, float radius, bool upBeforeDrag,  bool linearElevation, bool rightClick) override
         {
-            Point<int> pos = event.getPosition();
+            auto pos = event.getPosition();
             const float azi = -1.0f * centre.getAngleToPoint(pos);
             const float azimuthInDegrees { Conversions<float>::radiansToDegrees (azi) };
 
@@ -248,7 +247,7 @@ public:
                 }
 
                 if (linearElevation)
-                    r = std::sin(r * MathConstants<float>::halfPi);
+                    r = std::sin (r * juce::MathConstants<float>::halfPi);
                 float ele = std::acos (r);
                 if (! upBeforeDrag) ele *= -1.0f;
 
@@ -264,7 +263,7 @@ public:
         {
             azimuth.endChangeGesture();
             elevation.endChangeGesture();
-        };
+        }
 
         const float getAzimuthInRadians()
         {
@@ -281,32 +280,32 @@ public:
         /*
          Get cartesian coordinates
          */
-        Vector3D<float> getCoordinates() override
+        juce::Vector3D<float> getCoordinates() override
         {
             return Conversions<float>::sphericalToCartesian (getAzimuthInRadians(), getElevationInRadians());
-        };
+        }
 
     private:
-        AudioProcessorParameter& azimuth;
-        NormalisableRange<float> azimuthRange;
-        AudioProcessorParameter& elevation;
-        NormalisableRange<float> elevationRange;
+        juce::AudioProcessorParameter& azimuth;
+        juce::NormalisableRange<float> azimuthRange;
+        juce::AudioProcessorParameter& elevation;
+        juce::NormalisableRange<float> elevationRange;
     };
 
     class RollWidthParameterElement : public Element
     {
     public:
-        RollWidthParameterElement(AzimuthElevationParameterElement& center, AudioProcessorParameter& rollParameter, NormalisableRange<float> rollParameterRange, AudioProcessorParameter& widthParameter, NormalisableRange<float> widthParameterRange) : Element(), centerElement (center), roll (rollParameter), rollRange(rollParameterRange), width (widthParameter), widthRange (widthParameterRange) {}
+        RollWidthParameterElement (AzimuthElevationParameterElement& center, juce::AudioProcessorParameter& rollParameter, juce::NormalisableRange<float> rollParameterRange, juce::AudioProcessorParameter& widthParameter, juce::NormalisableRange<float> widthParameterRange) : centerElement (center), roll (rollParameter), rollRange(rollParameterRange), width (widthParameter), widthRange (widthParameterRange) {}
 
         void startMovement() override
         {
             roll.beginChangeGesture();
             width.beginChangeGesture();
-        };
+        }
 
-        void moveElement (const MouseEvent &event, Point<int> centre, float radius, bool upBeforeDrag, bool linearElevation, bool rightClick) override
+        void moveElement (const juce::MouseEvent &event, juce::Point<int> centre, float radius, bool upBeforeDrag, bool linearElevation, bool rightClick) override
         {
-            Point<int> pos = event.getPosition();
+            juce::Point<int> pos = event.getPosition();
             const float azi = -1.0f * centre.getAngleToPoint (pos);
             float r = centre.getDistanceFrom(pos) / radius;
             if (r > 1.0f)
@@ -316,15 +315,15 @@ public:
             }
 
             if (linearElevation)
-                r = std::sin (r * MathConstants<float>::halfPi);
+                r = std::sin (r * juce::MathConstants<float>::halfPi);
 
             float ele = std::acos (r);
             if (! upBeforeDrag) ele *= -1.0f;
 
-            Vector3D<float> posXYZ (Conversions<float>::sphericalToCartesian (azi, ele));
+            auto posXYZ = Conversions<float>::sphericalToCartesian (azi, ele);
 
             // ==== calculate width
-            Vector3D<float> dPos = posXYZ - centerElement.getCoordinates();
+            juce::Vector3D<float> dPos = posXYZ - centerElement.getCoordinates();
             const float alpha = 4.0f * std::asin (dPos.length() / 2.0f);
             width.setValueNotifyingHost (widthRange.convertTo0to1 (Conversions<float>::radiansToDegrees (alpha)));
 
@@ -350,12 +349,12 @@ public:
         {
             roll.endChangeGesture();
             width.endChangeGesture();
-        };
+        }
 
         /*
          Get cartesian coordinates
          */
-        Vector3D<float> getCoordinates() override
+        juce::Vector3D<float> getCoordinates() override
         {
             float ypr[3];
             ypr[0] = centerElement.getAzimuthInRadians();
@@ -375,61 +374,62 @@ public:
             iem::Quaternion<float> quatL = quat * quatLRot;
 
             return quatL.getCartesian();
-        };
+        }
 
         void setMirrored (bool mirrored) { isMirrored = mirrored; }
 
     private:
         AzimuthElevationParameterElement& centerElement;
-        AudioProcessorParameter& roll;
-        NormalisableRange<float> rollRange;
-        AudioProcessorParameter& width;
-        NormalisableRange<float> widthRange;
+        juce::AudioProcessorParameter& roll;
+        juce::NormalisableRange<float> rollRange;
+        juce::AudioProcessorParameter& width;
+        juce::NormalisableRange<float> widthRange;
         bool isMirrored = false;
     };
 
-    void resized () override {
+    void resized() override
+    {
         background.setBounds(getLocalBounds());
-        const Rectangle<float> sphere(getLocalBounds().reduced(10, 10).toFloat());
+        const auto sphere = getLocalBounds().reduced(10, 10).toFloat();
 
-        radius = 0.5f * jmin(sphere.getWidth(), sphere.getHeight());
+        radius = 0.5f * juce::jmin (sphere.getWidth(), sphere.getHeight());
         centre = getLocalBounds().getCentre();
         sphereArea.setBounds(0, 0, 2*radius, 2*radius);
         sphereArea.setCentre(centre.toFloat());
     }
 
-    void paintOverChildren (Graphics& g) override
+    void paintOverChildren (juce::Graphics& g) override
     {
-        const Rectangle<float> bounds = getLocalBounds().toFloat();
+        const auto bounds = getLocalBounds().toFloat();
         const float centreX = bounds.getCentreX();
         const float centreY = bounds.getCentreY();
 
-        g.setFont (getLookAndFeel().getTypefaceForFont (Font (12.0f, 1)));
+        g.setFont (getLookAndFeel().getTypefaceForFont (juce::Font (12.0f, 1)));
 
         const int size = elements.size();
         for (int i = 0; i < size; ++i)
         {
             SpherePanner::Element* handle = elements.getUnchecked (i);
 
-            Vector3D<float> pos = handle->getCoordinates();
+            auto pos = handle->getCoordinates();
             const bool isUp = pos.z >= -0.0f;
 
             const float diam = 15.0f + 4.0f * pos.z;
-            const Colour colour = handle->isActive() ? handle->getColour() : Colours::grey;
+            const juce::Colour colour = handle->isActive() ? handle->getColour() : juce::Colours::grey;
             g.setColour (colour);
 
             if (linearElevation)
             {
                 const float r = sqrt (pos.y * pos.y + pos.x * pos.x);
-                const float factor = std::asin (r) / r / MathConstants<float>::halfPi;
+                const float factor = std::asin (r) / r / juce::MathConstants<float>::halfPi;
                 pos *= factor;
             }
 
-            const Rectangle<float> circleArea (centreX - pos.y * radius - diam / 2, centreY - pos.x * radius - diam / 2, diam, diam);
-            Path panPos;
+            const juce::Rectangle<float> circleArea (centreX - pos.y * radius - diam / 2, centreY - pos.x * radius - diam / 2, diam, diam);
+            juce::Path panPos;
 
             panPos.addEllipse (circleArea);
-            g.strokePath (panPos, PathStrokeType (1.0f));
+            g.strokePath (panPos, juce::PathStrokeType (1.0f));
 
             if (i == activeElem)
             {
@@ -442,18 +442,18 @@ public:
             g.setColour (isUp ? handle->getTextColour() : colour);
 
             g.setFont (isUp ? 15.0f : 10.0f);
-            g.drawText (handle->getLabel(), circleArea.toNearestInt(), Justification::centred, false);
+            g.drawText (handle->getLabel(), circleArea.toNearestInt(), juce::Justification::centred, false);
         }
-    };
+    }
 
 
-    void mouseWheelMove (const MouseEvent &event, const MouseWheelDetails &wheel) override
+    void mouseWheelMove (const juce::MouseEvent &event, const juce::MouseWheelDetails &wheel) override
     {
         for (int i = listeners.size(); --i >= 0;)
             listeners.getUnchecked(i)->mouseWheelOnSpherePannerMoved (this, event, wheel);
     }
 
-    void mouseMove (const MouseEvent &event) override
+    void mouseMove (const juce::MouseEvent &event) override
     {
         const int oldActiveElem = activeElem;
         activeElem = -1;
@@ -463,8 +463,8 @@ public:
         if (nElem > 0)
         {
             const auto centre = getLocalBounds().getCentre();
-            const Point<int> dif = centre - event.getPosition();
-            const Point<float> mousePos (dif.y / radius, dif.x / radius); // scale and swap xy
+            const juce::Point<int> dif = centre - event.getPosition();
+            const juce::Point<float> mousePos (dif.y / radius, dif.x / radius); // scale and swap xy
 
             int highestPriority = -1;
             int smallestDist = 123456789; // basically infinity
@@ -477,11 +477,11 @@ public:
                 if (linearElevation)
                 {
                     const float r = sqrt (elementPosition.y * elementPosition.y + elementPosition.x * elementPosition.x);
-                    const float factor = std::asin (r) / r / MathConstants<float>::halfPi;
+                    const float factor = std::asin (r) / r / juce::MathConstants<float>::halfPi;
                     elementPosition *= factor;
                 }
 
-                const Point<float> connection (mousePos.x - elementPosition.x, mousePos.y - elementPosition.y);
+                const juce::Point<float> connection (mousePos.x - elementPosition.x, mousePos.y - elementPosition.y);
                 const auto distance = connection.getDistanceFromOrigin();
 
                 if (distance <= handle->getGrabRadius())
@@ -506,7 +506,7 @@ public:
             repaint();
     }
     
-    void mouseDrag (const MouseEvent &event) override
+    void mouseDrag (const juce::MouseEvent &event) override
     {
         const bool rightClick = event.mods.isRightButtonDown();
         if (activeElem != -1)
@@ -516,19 +516,19 @@ public:
         }
     }
 
-    void mouseDown (const MouseEvent &event) override
+    void mouseDown (const juce::MouseEvent &event) override
     {
         if (activeElem != -1)
             elements.getUnchecked (activeElem)->startMovement();
     }
 
-    void mouseUp (const MouseEvent &event) override
+    void mouseUp (const juce::MouseEvent &event) override
     {
         if (activeElem != -1)
             elements.getUnchecked (activeElem)->stopMovement();
     }
 
-    void mouseDoubleClick (const MouseEvent &event) override
+    void mouseDoubleClick (const juce::MouseEvent &event) override
     {
         setElevationStyle(! linearElevation);
         background.repaint();
@@ -540,39 +540,39 @@ public:
         jassert (listener != nullptr);
         if (listener != nullptr)
             listeners.add (listener);
-    };
+    }
 
     void removeListener (Listener* const listener)
     {
         listeners.removeFirstMatchingValue (listener);
-    };
+    }
 
     void addElement (Element* const element)
     {
         jassert (element != nullptr);
         if (element != nullptr)
             elements.addIfNotAlreadyThere (element);
-    };
+    }
 
     void removeElement (Element* const element)
     {
         elements.removeFirstMatchingValue (element);
-    };
+    }
 
     void setElevationStyle (bool linear)
     {
         linearElevation = linear;
         background.setElevationStyle(linear);
-    };
+    }
 
-private:
+protected:
     float radius = 1.0f;
-    Rectangle<float> sphereArea;
-    Point<int> centre;
+    juce::Rectangle<float> sphereArea;
+    juce::Point<int> centre;
     int activeElem = -1;
     bool activeElemWasUpBeforeDrag;
-    Array<Listener*> listeners;
-    Array<Element*> elements;
+    juce::Array<Listener*> listeners;
+    juce::Array<Element*> elements;
     bool linearElevation = false;
     SpherePannerBackground background;
 };
